<?php 
/* 
 ----------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 ----------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ------------------------------------------------------------------------
 */
//lv_LV

$LANG=array();


$LANG['backup'][0]="Datubāzes kopija (SQL Dump)"; 
$LANG['backup'][1]="Arhivēšana XML failā (XML Dump)"; 
$LANG['backup'][11]="Izmērs"; 
$LANG['backup'][13]="Apskatīt/Lejupielādēt"; 
$LANG['backup'][16]="Replace the current database with the backup file:"; 
$LANG['backup'][17]="Dzēst šo datni"; 
$LANG['backup'][18]="Saglabāt datubāzes rezerves kopiju"; 
$LANG['backup'][19]="Tagad"; 
$LANG['backup'][21]="Šāda datne jau ir"; 
$LANG['backup'][22]="Nav iespējams atrast baitu"; 
$LANG['backup'][23]="Mysql kļūda sākot no"; 
$LANG['backup'][24]="Automātiska pradresācija, lai atceltu - noklikšķiniet"; 

$LANG['bookmark'][1]="grāmatzīme"; 
$LANG['bookmark'][2]="Partial load of the bookmark."; 
$LANG['bookmark'][3]="Jums nav saglabāta neviena grāmatzīme."; 
$LANG['bookmark'][4]="Jauna grāmatzīme"; 
$LANG['bookmark'][5]="Publiskās grāmatzīmes"; 
$LANG['bookmark'][6]="Apstiprināt pēc noklusējuma"; 

$LANG['buttons'][0]="Meklēt"; 
$LANG['buttons'][2]="Nosūtīt"; 
$LANG['buttons'][3]="Piesaistīt"; 
$LANG['buttons'][4]="Instalēt"; 
$LANG['buttons'][5]="Atinstalēt"; 
$LANG['buttons'][6]="Dzēst"; 
$LANG['buttons'][7]="Saglabāt"; 
$LANG['buttons'][8]="Pievienot"; 
$LANG['buttons'][9]="Savienot"; 
$LANG['buttons'][10]="Atvienot"; 
$LANG['buttons'][11]="Nākamā"; 
$LANG['buttons'][12]="Iepriekšējā"; 
$LANG['buttons'][13]="Atpakaļ"; 
$LANG['buttons'][14]="Jaunināt"; 
$LANG['buttons'][15]="Ieplānot"; 
$LANG['buttons'][16]="Tukšs"; 
$LANG['buttons'][17]="Invert the selection"; 
$LANG['buttons'][18]="Iezīmēt visu"; 
$LANG['buttons'][19]="Neiezīmēt visu"; 
$LANG['buttons'][20]="Pārvietot"; 
$LANG['buttons'][21]="Atjaunot"; 
$LANG['buttons'][22]="Atbrīvot (Purge)"; 
$LANG['buttons'][23]="Rādīt"; 
$LANG['buttons'][24]="Uz augšu"; 
$LANG['buttons'][25]="Uz leju"; 
$LANG['buttons'][27]="Saglabāt lapu PDF datnē"; 
$LANG['buttons'][28]="Saglabāt lapu SLK datnē"; 
$LANG['buttons'][29]="Visas lapas PDF datnē"; 
$LANG['buttons'][30]="Visas lapas SLK datnē"; 
$LANG['buttons'][31]="Eksportēt"; 
$LANG['buttons'][32]="Pēdējā"; 
$LANG['buttons'][33]="Pirmā lapa"; 
$LANG['buttons'][34]="Atcelt"; 
$LANG['buttons'][37]="Importēt"; 
$LANG['buttons'][38]="Atslēgt"; 
$LANG['buttons'][39]="Aizvietot"; 
$LANG['buttons'][40]="Rādīt visu"; 
$LANG['buttons'][41]="Aktivizēt"; 
$LANG['buttons'][42]="Deaktivizēt"; 
$LANG['buttons'][43]="Pārlūkot"; 
$LANG['buttons'][44]="Saglabāt lapu CSV datnē"; 
$LANG['buttons'][45]="Visas lapas CSV datnē"; 
$LANG['buttons'][46]="Pirms"; 
$LANG['buttons'][47]="Pēc"; 
$LANG['buttons'][48]="Pārvietot"; 
$LANG['buttons'][49]="Saglabāt (Preserve)"; 
$LANG['buttons'][50]="Pārbaudīt"; 
$LANG['buttons'][51]="Saglabāt"; 
$LANG['buttons'][52]="Ielādēt"; 
$LANG['buttons'][53]="Clean"; 
$LANG['buttons'][55]="First"; 
$LANG['buttons'][56]="Pēdējais"; 
$LANG['buttons'][57]="Execute"; 
$LANG['buttons'][58]="Atjaunināt"; 
$LANG['buttons'][59]="Dissociate"; 

$LANG['calendar'][0]="GGGG-MM-DD"; 
$LANG['calendar'][1]="DD-MM-GGGG"; 
$LANG['calendar'][2]="MM-DD-GGGG"; 

$LANG['calendarD'][0]="S"; 
$LANG['calendarD'][1]="P"; 
$LANG['calendarD'][2]="O"; 
$LANG['calendarD'][3]="T"; 
$LANG['calendarD'][4]="C"; 
$LANG['calendarD'][5]="P"; 
$LANG['calendarD'][6]="S"; 

$LANG['calendarDay'][0]="Svētdiena"; 
$LANG['calendarDay'][1]="Pirmdiena"; 
$LANG['calendarDay'][2]="Otrdiena"; 
$LANG['calendarDay'][3]="Trešdiena"; 
$LANG['calendarDay'][4]="Ceturtdiena"; 
$LANG['calendarDay'][5]="Piektdiena"; 
$LANG['calendarDay'][6]="Sestdiena"; 

$LANG['calendarM'][0]="Janvāris"; 
$LANG['calendarM'][1]="Februāris"; 
$LANG['calendarM'][2]="Marts"; 
$LANG['calendarM'][3]="Aprīlis"; 
$LANG['calendarM'][4]="Maijs"; 
$LANG['calendarM'][5]="Jūnijs"; 
$LANG['calendarM'][6]="Jūlijs"; 
$LANG['calendarM'][7]="Augusts"; 
$LANG['calendarM'][8]="Septembris"; 
$LANG['calendarM'][9]="Oktobris"; 
$LANG['calendarM'][10]="Novembris"; 
$LANG['calendarM'][11]="Decembris"; 

$LANG['cartridges'][0]="Kasetne"; 
$LANG['cartridges'][7]="Kasetnes netika atrastas"; 
$LANG['cartridges'][9]="Nav kasetnes"; 
$LANG['cartridges'][10]="Toneris"; 
$LANG['cartridges'][11]="Ink-Jet"; 
$LANG['cartridges'][12]="Kasetnes tips"; 
$LANG['cartridges'][13]="Jauna"; 
$LANG['cartridges'][14]="Lietota"; 
$LANG['cartridges'][15]="Lietotas"; 
$LANG['cartridges'][16]="Kasetne(s)"; 
$LANG['cartridges'][20]="Jauna"; 
$LANG['cartridges'][21]="Lietota"; 
$LANG['cartridges'][22]="Lietotas"; 
$LANG['cartridges'][24]="Pievienot datumu"; 
$LANG['cartridges'][27]="Ieslēgts"; 
$LANG['cartridges'][29]="Lietošanas beigas (End of life)"; 
$LANG['cartridges'][32]="Savietojama ar printeriem"; 
$LANG['cartridges'][33]="Lietotas kasetnes"; 
$LANG['cartridges'][34]="Nav brīvu kasetņu"; 
$LANG['cartridges'][35]="Lietotas kasetnes"; 
$LANG['cartridges'][37]="Lentes"; 
$LANG['cartridges'][39]="Printera skaitītājs (Printer counter)"; 
$LANG['cartridges'][40]="Vidējais uzglabāšanas ilgums"; 
$LANG['cartridges'][41]="Vidējais lietošanas ilgums"; 
$LANG['cartridges'][42]="Vidējais izdrukāto lappušu skaits"; 

$LANG['central'][2]="Pēdējā"; 
$LANG['central'][4]="Nav notikumu"; 
$LANG['central'][5]="Sākumlapa"; 
$LANG['central'][6]="Beigt darbu"; 
$LANG['central'][7]="Palīdzība"; 
$LANG['central'][8]="Papildinājumi"; 
$LANG['central'][9]="Tavi pieteikumi apstrādē"; 
$LANG['central'][10]="Jauni pieteikumi"; 
$LANG['central'][12]="Savs skats"; 
$LANG['central'][13]="Globālais skats"; 
$LANG['central'][14]="Grupas skats"; 
$LANG['central'][18]="Your tickets to close"; 
$LANG['central'][19]="Your tickets to validate"; 

$LANG['choice'][0]="Nē"; 
$LANG['choice'][1]="Jā"; 

$LANG['common'][0]="Bez vārda"; 
$LANG['common'][1]="Objekts"; 
$LANG['common'][2]="ID"; 
$LANG['common'][3]="Show the trash"; 
$LANG['common'][4]="Web"; 
$LANG['common'][5]="Ražotājs"; 
$LANG['common'][6]="Sagataves nosaukums"; 
$LANG['common'][7]="Izvēlieties sagatavi"; 
$LANG['common'][8]="Pārvaldīt sagataves..."; 
$LANG['common'][9]="Pievienot sagatavi..."; 
$LANG['common'][10]="Atbildīgais tehniķis"; 
$LANG['common'][11]="Ierobežots skatījums"; 
$LANG['common'][12]="Iestatīšana"; 
$LANG['common'][13]="Sagatave"; 
$LANG['common'][14]="Sagataves"; 
$LANG['common'][15]="Atrašanās vieta"; 
$LANG['common'][16]="Vārdu"; 
$LANG['common'][17]="Tips"; 
$LANG['common'][18]="Alternatīvs lietotājvārds"; 
$LANG['common'][19]="Sērijas numurs"; 
$LANG['common'][20]="Inventāra Nr."; 
$LANG['common'][21]="Alternatīvā lietotājvārda numurs"; 
$LANG['common'][22]="Modelis"; 
$LANG['common'][23]="Darbība veiksmīgi paveikta"; 
$LANG['common'][24]="Nav izvēlēta neviena sastāvdaļa vai kļūdaini norādīta darbība"; 
$LANG['common'][25]="Piezīmes"; 
$LANG['common'][26]="Pēdējās izmaiņas"; 
$LANG['common'][27]="Datums"; 
$LANG['common'][28]="Dzēsts"; 
$LANG['common'][29]="Papildus spraudņi (plugins)"; 
$LANG['common'][30]="Jauns objekts"; 
$LANG['common'][31]="Tukša sagatave"; 
$LANG['common'][32]="Īpašības"; 
$LANG['common'][33]="Pavisam"; 
$LANG['common'][34]="Lietotājs"; 
$LANG['common'][35]="Grupa"; 
$LANG['common'][36]="Kategorija"; 
$LANG['common'][37]="Writer"; 
$LANG['common'][38]="Use unitary management"; 
$LANG['common'][39]="Pavairojiet elementu skaitu atbilstoši savienojumu skaitam"; 
$LANG['common'][40]="Do you really want to use unitary management this item ?"; 
$LANG['common'][41]="Paziņojumi uz epastu"; 
$LANG['common'][42]="Mobile phone"; 
$LANG['common'][43]="Vārds"; 
$LANG['common'][44]="Noklusētā vērtība/s"; 
$LANG['common'][45]="MB max"; 
$LANG['common'][46]="Vcard"; 
$LANG['common'][47]="Progress"; 
$LANG['common'][48]="Uzvārds"; 
$LANG['common'][49]="Nekas"; 
$LANG['common'][50]="Apstiprināt reālu dzēšanu?"; 
$LANG['common'][51]="Pilns vārds"; 
$LANG['common'][52]="Serveris"; 
$LANG['common'][53]="Saraksts"; 
$LANG['common'][54]="Objekts netika atrasts"; 
$LANG['common'][55]="Tiešām vēlies dzēst šo sastāvdaļu?"; 
$LANG['common'][56]="Standard interface"; 
$LANG['common'][57]="Virsraksts"; 
$LANG['common'][58]="Lielākā vērtība"; 
$LANG['common'][59]="Globāls"; 
$LANG['common'][60]="Aktīvs"; 
$LANG['common'][61]="Nezināma kļūda"; 
$LANG['common'][62]="Cits"; 
$LANG['common'][63]="Kļūda(s)"; 
$LANG['common'][64]="Vadītājs"; 
$LANG['common'][65]="Saskarne"; 
$LANG['common'][66]="Viss"; 
$LANG['common'][67]="Citi"; 
$LANG['common'][68]="Ainava"; 
$LANG['common'][69]="Portrets"; 
$LANG['common'][70]="Objekts pievienots"; 
$LANG['common'][71]="Objekts atjaunināts"; 
$LANG['common'][72]="Item successfully deleted"; 
$LANG['common'][73]="Item successfully purged"; 
$LANG['common'][74]="Objekts atjaunots"; 
$LANG['common'][75]="Nav atļaujas šajā nodaļā šo objektu uzstādīt kā rekursīvu."; 
$LANG['common'][76]="Publisks"; 
$LANG['common'][77]="Privāts"; 
$LANG['common'][78]="Uzstādīt kā publisku"; 
$LANG['common'][79]="Set personal"; 
$LANG['common'][80]="During loading..."; 
$LANG['common'][81]="Don't show deleted items"; 
$LANG['common'][82]="MB"; 
$LANG['common'][83]="You don't have permission to perform this action."; 
$LANG['common'][84]="Flag change forbidden. Linked items found."; 
$LANG['common'][85]="Change visibility in the child entities"; 
$LANG['common'][86]="You are not allowed to change the visibility flag for child entities."; 
$LANG['common'][87]="New card"; 
$LANG['common'][88]="Personal"; 
$LANG['common'][89]="Nav uzstādīts"; 
$LANG['common'][90]="Object"; 
$LANG['common'][91]="Can't change this attribute. It's inherited from its parent."; 
$LANG['common'][92]="Alternate username"; 
$LANG['common'][93]="New child heading"; 

$LANG['computers'][0]="Sējums"; 
$LANG['computers'][1]="Free percentage"; 
$LANG['computers'][2]="Free size"; 
$LANG['computers'][3]="Global size"; 
$LANG['computers'][4]="File system"; 
$LANG['computers'][5]="Mount point"; 
$LANG['computers'][6]="Partition"; 
$LANG['computers'][7]="Pievienot sējumu"; 
$LANG['computers'][8]="Sējumi"; 
$LANG['computers'][9]="Operating system"; 
$LANG['computers'][10]="Serial of the operating system"; 
$LANG['computers'][11]="Product ID of the operating system"; 
$LANG['computers'][14]="Ievietots"; 
$LANG['computers'][23]="Type of memory"; 
$LANG['computers'][24]="Memory (MB)"; 
$LANG['computers'][25]="Hard drive size"; 
$LANG['computers'][36]="Hard drive type"; 
$LANG['computers'][37]="Nav pievienotu monitoru."; 
$LANG['computers'][38]="Nav pievienotu printeru"; 
$LANG['computers'][39]="Printeris(i)"; 
$LANG['computers'][40]="Monitors(i)"; 
$LANG['computers'][46]="Ierīces"; 
$LANG['computers'][47]="Nav pievienotu ierīču"; 
$LANG['computers'][48]="Atrašanās vieta atjaunināta. Saistītie objekti tika pārvietoti uz jauno vietu."; 
$LANG['computers'][49]="Alternatīvais lietotājvārds atjaunināts. Saistītajiem objektiem norādīts alternatīvais lietotājvārds."; 
$LANG['computers'][50]="Lietotājs vai grupa atjaunināta. Saistītie objekti atjaunināti izmantojot šo informāciju."; 
$LANG['computers'][51]="Atjaunināt avotu"; 
$LANG['computers'][52]="Version of the operating system"; 
$LANG['computers'][53]="Servispaka"; 
$LANG['computers'][54]="Nav pievienotu telefonu"; 
$LANG['computers'][55]="Telefons(i)"; 
$LANG['computers'][56]="Informācija atjaunināta. Saistītie objekti atjaunināti izmantojot šo informāciju."; 

$LANG['connect'][0]="Tieši savienojumi"; 
$LANG['connect'][1]="Nav savienots."; 
$LANG['connect'][15]="Automātiski atjaunināt norādītos objektus"; 
$LANG['connect'][16]="Uzmanību!! Sekojošie objekti ar divām dažādām aparatūrām nesakrīt!"; 

$LANG['consumables'][0]="Izlietojamais materiāls"; 
$LANG['consumables'][1]="Noliktavā"; 
$LANG['consumables'][2]="Atsauce"; 
$LANG['consumables'][7]="Izlietojamais materiāls netika atrasts"; 
$LANG['consumables'][9]="Nav izlietojama materiāla"; 
$LANG['consumables'][12]="Izlietojamā materiāla tips"; 
$LANG['consumables'][13]="Jauns"; 
$LANG['consumables'][15]="Lietots"; 
$LANG['consumables'][16]="Izlietojamais materiāls(i)"; 
$LANG['consumables'][20]="Jauns"; 
$LANG['consumables'][22]="Lietots"; 
$LANG['consumables'][23]="Stāvoklis"; 
$LANG['consumables'][26]="Izlietots"; 
$LANG['consumables'][32]="Izsniegt"; 
$LANG['consumables'][35]="Used consumables"; 
$LANG['consumables'][36]="Atrašanās vieta noliktavā"; 
$LANG['consumables'][37]="Atgriezt noliktavā"; 
$LANG['consumables'][38]="Brīdinājuma slieksnis"; 

$LANG['contract'][0]="Contract expired since the"; 
$LANG['contract'][1]="Contract with notice since the"; 

$LANG['crontask'][0]="Automatic actions"; 
$LANG['crontask'][1]="Synchronize equipments from OCSNG"; 
$LANG['crontask'][2]="Send alarms on cartridges"; 
$LANG['crontask'][3]="Send alarms on consumables"; 
$LANG['crontask'][4]="Send alarms on expired licenses"; 
$LANG['crontask'][5]="Send alarms on contracts"; 
$LANG['crontask'][6]="Send alarms on financial information"; 
$LANG['crontask'][7]="Clean old logs"; 
$LANG['crontask'][8]="Database optimization"; 
$LANG['crontask'][9]="Retrieve email (Mail receivers)"; 
$LANG['crontask'][10]="Check the MySQL replica"; 
$LANG['crontask'][11]="Check for new updates"; 
$LANG['crontask'][12]="Clean expired sessions"; 
$LANG['crontask'][13]="Clean generated graphics"; 
$LANG['crontask'][14]="Automatic tickets closing"; 
$LANG['crontask'][15]="Not solved tickets"; 
$LANG['crontask'][31]="Disabled"; 
$LANG['crontask'][32]="Scheduled"; 
$LANG['crontask'][33]="Running"; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="CLI"; 
$LANG['crontask'][36]="Run mode"; 
$LANG['crontask'][37]="Run frequency"; 
$LANG['crontask'][38]="Run period"; 
$LANG['crontask'][39]="Number of email to retrieve"; 
$LANG['crontask'][40]="Last run"; 
$LANG['crontask'][41]="Next run"; 
$LANG['crontask'][42]="As soon as possible"; 
$LANG['crontask'][43]="No action pending"; 
$LANG['crontask'][44]="Action completed, partially processed"; 
$LANG['crontask'][45]="Action completed, fully processed"; 
$LANG['crontask'][46]="Action completed, no processing required"; 
$LANG['crontask'][47]="Last run list"; 
$LANG['crontask'][48]="Sākt"; 
$LANG['crontask'][50]="Run count"; 
$LANG['crontask'][51]="Minimal time"; 
$LANG['crontask'][52]="Maximal time"; 
$LANG['crontask'][53]="Average time"; 
$LANG['crontask'][55]="Minimal count"; 
$LANG['crontask'][56]="Maximal count"; 
$LANG['crontask'][57]="Average count"; 
$LANG['crontask'][58]="Total count"; 
$LANG['crontask'][59]="Average speed"; 
$LANG['crontask'][60]="System lock"; 
$LANG['crontask'][61]="Disabled plugin"; 
$LANG['crontask'][62]="Elements"; 

$LANG['devices'][0]="Pievienot jaunu komponenti"; 
$LANG['devices'][1]="Cietais disks"; 
$LANG['devices'][2]="Videokarte"; 
$LANG['devices'][3]="Tīkla karte"; 
$LANG['devices'][4]="Procesors"; 
$LANG['devices'][5]="Mātes plate"; 
$LANG['devices'][6]="Memory"; 
$LANG['devices'][7]="Skaņas karte"; 
$LANG['devices'][19]="Diskiekārtas"; 
$LANG['devices'][20]="Kontrolieri"; 
$LANG['devices'][21]="Citas komponentes"; 
$LANG['devices'][22]="Korpusi"; 
$LANG['devices'][23]="Barošanas bloks"; 
$LANG['devices'][24]="pēc noklusējuma"; 
$LANG['devices'][25]="Pievienot komponenti"; 
$LANG['devices'][26]="Dzēst komponenti"; 

$LANG['device_case'][0]="Izmērs"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="Rakstītājs"; 
$LANG['device_drive'][1]="Ātrums"; 

$LANG['device_hdd'][0]="Ātrums (RPM)"; 
$LANG['device_hdd'][1]="Kešatmiņa"; 
$LANG['device_hdd'][4]="Ietilpība"; 

$LANG['device_iface'][0]="Ātrums"; 
$LANG['device_iface'][2]="MAC adrese"; 

$LANG['device_moboard'][0]="Čipsets"; 

$LANG['device_power'][0]="Jauda"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="Frekvence"; 
$LANG['device_ram'][2]="Izmērs"; 

$LANG['document'][1]="Checksum (SHA1)"; 
$LANG['document'][2]="Datne"; 
$LANG['document'][3]="Virsraksts"; 
$LANG['document'][4]="MIME tips"; 
$LANG['document'][7]="Dokumenta tips"; 
$LANG['document'][9]="Paplašinājums"; 
$LANG['document'][10]="Ikona"; 
$LANG['document'][11]="Lejupielāde ar atļaujām"; 
$LANG['document'][15]="Lejupielādēt"; 
$LANG['document'][16]="Pievienot dokumentu"; 
$LANG['document'][18]="Dokuments"; 
$LANG['document'][19]="Saistītie objekti"; 
$LANG['document'][21]="Saistītie dokumenti"; 
$LANG['document'][22]="Pašreizējā datne"; 
$LANG['document'][23]="File too large to be added."; 
$LANG['document'][24]="Datne dzēsta"; 
$LANG['document'][25]="Nevarēja izdzēst datni"; 
$LANG['document'][26]="Augšupielāde veiksmīga."; 
$LANG['document'][27]="Pārāk liels fails vai mēģinājums sabojāt sistēmu sūtot lielas datnes. Pagaidu datnes pārvietošana neveiksmīga."; 
$LANG['document'][28]="No file specified."; 
$LANG['document'][29]="Nevarēja izveidot mapi"; 
$LANG['document'][30]="Pārbaudi, vai Tev ir nepieciešamās piekļuves tiesības"; 
$LANG['document'][31]="Dokumentu mape neeksistē"; 
$LANG['document'][32]="Neatļauts datnes tips"; 
$LANG['document'][33]="Interneta saite"; 
$LANG['document'][34]="Izveidot mapi"; 
$LANG['document'][35]="Mape augšupielādes veikšanai neeksistē"; 
$LANG['document'][36]="Lietot uz FTP novietotu datni"; 
$LANG['document'][37]="Nav datnes"; 
$LANG['document'][38]="Datne nav atrasta"; 
$LANG['document'][39]="Dokuments pārvietots"; 
$LANG['document'][40]="Datni neizdevās pārvietot"; 
$LANG['document'][41]="Dokuments nokopēts"; 
$LANG['document'][42]="Pievienoja"; 
$LANG['document'][43]="Nezināma datne"; 
$LANG['document'][44]="Neatļauts datnes nosaukums"; 
$LANG['document'][45]="Pieeja datnei slēgta"; 
$LANG['document'][46]="Neizdevās nosūtīt datni. (par lielu?)"; 
$LANG['document'][48]="A document with that filename has already been attached to (another) record"; 
$LANG['document'][49]="File is altered (bad checksum)"; 
$LANG['document'][50]="Pievienoti vienumi"; 

$LANG['entity'][0]="Nodaļa"; 
$LANG['entity'][2]="Galvenā nodaļa"; 
$LANG['entity'][3]="Piesaistīt nodaļai"; 
$LANG['entity'][5]="Automātiska datoru pievienošana"; 
$LANG['entity'][6]="Automātiska lietotāju pievienošana"; 
$LANG['entity'][7]="koka struktūra"; 
$LANG['entity'][8]="Pēc nodaļas"; 
$LANG['entity'][9]="Apakšnodaļas"; 
$LANG['entity'][10]="Izvēlieties vēlamo apakšnodaļu"; 
$LANG['entity'][11]="skatīt nodaļu un tās apakšnodaļas"; 
$LANG['entity'][12]="LDAP attribute identifying entity"; 
$LANG['entity'][13]="TAG identifying entity"; 
$LANG['entity'][14]="Advanced informations"; 
$LANG['entity'][15]="LDAP directory of an entity"; 
$LANG['entity'][16]="Search filter (if needed)"; 
$LANG['entity'][17]="Automatic closing configuration"; 
$LANG['entity'][18]="Automatic closing of the tickets after"; 

$LANG['event'][0]="Source"; 
$LANG['event'][2]="Serviss"; 
$LANG['event'][3]="Līmenis"; 
$LANG['event'][4]="Ziņojums"; 
$LANG['event'][18]="Lauks"; 
$LANG['event'][19]="Jaunināt"; 
$LANG['event'][20]="Nav vēsturisku"; 

$LANG['financial'][1]="Līgums"; 
$LANG['financial'][2]="Ir dzīves"; 
$LANG['financial'][3]="Finansu informācija"; 
$LANG['financial'][4]="Numurs"; 
$LANG['financial'][5]="Izmaksas"; 
$LANG['financial'][6]="Līguma tips"; 
$LANG['financial'][8]="Ilgums"; 
$LANG['financial'][9]="gads(i)"; 
$LANG['financial'][10]="Paziņojums"; 
$LANG['financial'][11]="Pavadzīmes termiņš"; 
$LANG['financial'][13]="Konta numurs"; 
$LANG['financial'][14]="Pirkuma datums"; 
$LANG['financial'][15]="Warranty duration"; 
$LANG['financial'][16]="Garantijas informācija"; 
$LANG['financial'][18]="Pasūtījuma nr."; 
$LANG['financial'][19]="Piegāde no"; 
$LANG['financial'][20]="Imobilizācijas nr."; 
$LANG['financial'][21]="Vērtība"; 
$LANG['financial'][22]="Amortizācijas tips"; 
$LANG['financial'][23]="Amortizācijas ilgums"; 
$LANG['financial'][24]="Pievienot kontaktpersonu..."; 
$LANG['financial'][25]="Pievienot piegādātāju..."; 
$LANG['financial'][26]="Piegādātājs"; 
$LANG['financial'][30]="Fakss"; 
$LANG['financial'][33]="Pievienot kontaktpersonu"; 
$LANG['financial'][36]="Pievienot līgumu"; 
$LANG['financial'][42]="Komerciāls"; 
$LANG['financial'][43]="Tehniķis"; 
$LANG['financial'][44]="Adrese"; 
$LANG['financial'][45]="Mājaslapa"; 
$LANG['financial'][46]="Saistītie kontakti"; 
$LANG['financial'][47]="Lineārs"; 
$LANG['financial'][48]="Samazinās"; 
$LANG['financial'][50]="Aizdevums"; 
$LANG['financial'][51]="Īrēšana"; 
$LANG['financial'][52]="Īre"; 
$LANG['financial'][53]="Apdrošināšana"; 
$LANG['financial'][54]="Aparatūras atbalsts"; 
$LANG['financial'][55]="Programmatūras atbalsts"; 
$LANG['financial'][56]="Piedāvātais serviss"; 
$LANG['financial'][57]="mēnesis"; 
$LANG['financial'][59]="Atbalsta stundas"; 
$LANG['financial'][60]="nedēļā"; 
$LANG['financial'][61]="Svētdienā"; 
$LANG['financial'][62]="Svētdienas un brīvdienas"; 
$LANG['financial'][65]="Saistītie piegādātāji"; 
$LANG['financial'][66]="Saistītie līgumi"; 
$LANG['financial'][68]="Aktivizēt finansiālo informāciju"; 
$LANG['financial'][69]="Līguma periods"; 
$LANG['financial'][76]="Sākuma datums"; 
$LANG['financial'][77]="Amortizācijas koeficients"; 
$LANG['financial'][78]="Garantijas beigu vērtība"; 
$LANG['financial'][79]="Trešās personas tips"; 
$LANG['financial'][80]="Garantijas beigu datums"; 
$LANG['financial'][81]="Konta neto vērtība"; 
$LANG['financial'][82]="Pavadzīmes nr."; 
$LANG['financial'][83]="Max number of items"; 
$LANG['financial'][84]="Šī tipa elementam finansiālā informācija ir tikai modelis elementiem kurus Jums būs jāpievieno."; 
$LANG['financial'][85]="Pieprasītais objekts nav atrasts"; 
$LANG['financial'][86]="End of contract"; 
$LANG['financial'][87]="Budžets"; 
$LANG['financial'][88]="Derīgs līdz:"; 
$LANG['financial'][89]="Kopējās lietošanas izmaksas (vērtība + tracking izmaksas)"; 
$LANG['financial'][90]="Lietošanas izmaksas (TCO) mēnesim"; 
$LANG['financial'][91]="Kopējās lietošanas izmaksas"; 
$LANG['financial'][92]="ANV"; 
$LANG['financial'][93]="Līgumi, kuri ir beigušies pēdējo 30 dienu laikā"; 
$LANG['financial'][94]="Līgumi, kuri beigsies pēc mazāk kā 7 dienām"; 
$LANG['financial'][95]="Līgumi, kuri beigsies pēc mazāk kā 30 dienām"; 
$LANG['financial'][96]="Līgumi, kuriem parādīsies brīdinājums pēc mazāk kā 7 dienām"; 
$LANG['financial'][97]="Līgumi, kuriem parādīsies brīdinājums pēc mazāk kā 30 dienām"; 
$LANG['financial'][98]="Izbeigšanās"; 
$LANG['financial'][99]="Izbeigšanās datums + brīdinājums"; 
$LANG['financial'][100]="Pasta kods"; 
$LANG['financial'][101]="Pilsēta"; 
$LANG['financial'][102]="Stāvoklis"; 
$LANG['financial'][103]="Valsts"; 
$LANG['financial'][104]="Saistītie objekti"; 
$LANG['financial'][105]="Īpašas piezīmes"; 
$LANG['financial'][106]="Ekspress"; 
$LANG['financial'][107]="Atjaunošana"; 
$LANG['financial'][108]="Total spent on the budget"; 
$LANG['financial'][109]="Total remaining on the budget"; 
$LANG['financial'][110]="Budgets"; 

$LANG['gmt'][0]="GMT"; 
$LANG['gmt'][1]="stunda(s)"; 
$LANG['gmt'][2]="h"; 

$LANG['help'][1]="Matrix of calculus for priority"; 
$LANG['help'][2]="Major"; 
$LANG['help'][3]="Ļoti augsts"; 
$LANG['help'][4]="Augsts"; 
$LANG['help'][5]="Vidējs"; 
$LANG['help'][6]="Zems"; 
$LANG['help'][7]="Ļoti zems"; 
$LANG['help'][8]="Informēt mani par problēmas risināšanas gaitu"; 
$LANG['help'][11]="Mans e-pasts"; 
$LANG['help'][14]="Sūtīt ziņojumu"; 
$LANG['help'][16]="If you want be notified about the action(s) taken, please enter your e-mail address."; 
$LANG['help'][18]="Jūsu ziņojums veiksmīgi nosūtīts."; 
$LANG['help'][19]="Paldies par palīdzības sistēmas izmantošanu."; 
$LANG['help'][22]="Meklēt pēc Jūsu datora ID"; 
$LANG['help'][23]="Enter the first letters (user, item name, serial or asset number)"; 
$LANG['help'][24]="Ierīces tips"; 
$LANG['help'][25]="Dators"; 
$LANG['help'][26]="Tīkla ierīce"; 
$LANG['help'][27]="Printeris"; 
$LANG['help'][28]="Monitors"; 
$LANG['help'][29]="Ierīce"; 
$LANG['help'][30]="Nav norādīta"; 
$LANG['help'][31]="Programmatūra"; 
$LANG['help'][35]="Tālrunis"; 
$LANG['help'][40]="Pieteikumam nav norādīts virsraksts."; 
$LANG['help'][41]="Pieteikumam nav norādīta kategorija."; 
$LANG['help'][42]="Very High"; 
$LANG['help'][43]="High"; 
$LANG['help'][44]="Medium"; 
$LANG['help'][45]="Low"; 
$LANG['help'][46]="Very Low"; 
$LANG['help'][47]="Very High"; 
$LANG['help'][48]="High"; 
$LANG['help'][49]="Medium"; 
$LANG['help'][50]="Low"; 
$LANG['help'][51]="Very Low"; 

$LANG['install'][0]="GLPI instalācija vai atjaunināšana"; 
$LANG['install'][1]="Izvēlieties 'Instalēt' lai sāktu jaunu GLPI instalāciju"; 
$LANG['install'][2]="Izvēlieties 'Atjaunināt' lai uzstādītu jaunāku GLPI versiju."; 
$LANG['install'][3]="Instalācija"; 
$LANG['install'][4]="Atjaunināt"; 
$LANG['install'][5]="Notiek servera darba vides un GLPI saderības pārbaude"; 
$LANG['install'][6]="Test done"; 
$LANG['install'][7]="Rezultāti"; 
$LANG['install'][8]="Pārbauda PHP parsētāju"; 
$LANG['install'][9]="You must install at least PHP5."; 
$LANG['install'][10]="GLPI is not compatible with the option zend.ze1_compatibility_mode = On."; 
$LANG['install'][11]="PHP version is at least 5.x - Perfect !"; 
$LANG['install'][12]="Sesiju tests"; 
$LANG['install'][13]="Jūsu PHP parseris neatbalsta sesijas!"; 
$LANG['install'][14]="Sesiju atbalsts pieejams - lieliski!"; 
$LANG['install'][15]="Pārbaudiet vai php.ini ir ieslēgts sesiju atbalsts"; 
$LANG['install'][16]="Pārbaudu rakstīšanas tiesības dump datnēm"; 
$LANG['install'][17]="Datni nav iespējams izveidot"; 
$LANG['install'][18]="Unofficial translations are also available"; 
$LANG['install'][19]="Datne tika izveidota, taču to nav iespējams dzēst."; 
$LANG['install'][20]="Izdevās izveidot un dzēst datni un mapi!"; 
$LANG['install'][21]="Pārbaudu rakstīšanas tiesības dokumentu datnēm"; 
$LANG['install'][22]="Fails tika izveiots - lieliski!"; 
$LANG['install'][23]="Pārbaudu rakstīšanas tiesības uzstādījumu datnēm"; 
$LANG['install'][24]="Initialization of the database"; 
$LANG['install'][25]="Turpināt?"; 
$LANG['install'][26]="Turpināt"; 
$LANG['install'][27]="Mēģiniet vēlreiz"; 
$LANG['install'][28]="Datubāzes savienojuma iestatīšana"; 
$LANG['install'][29]="Datubāzes pieslēgšanās parametri"; 
$LANG['install'][30]="Mysql server"; 
$LANG['install'][31]="Mysql user"; 
$LANG['install'][32]="Mysql password"; 
$LANG['install'][34]="Pārbauda savienojumu ar datubāzi"; 
$LANG['install'][35]="Nevaru pieslēgties datubāzei"; 
$LANG['install'][36]="Servera atbilde"; 
$LANG['install'][37]="The server or/and user field is empty"; 
$LANG['install'][38]="Lūdzu izvēlieties datubāzi:"; 
$LANG['install'][39]="Izveidot jaunu datubāzi vai izvēlēties kādu no esošajām:"; 
$LANG['install'][40]="Lūdzu izvēlieties datubāzi ko atjaunot:"; 
$LANG['install'][41]="Datubāzi nav iespējams iznatot:"; 
$LANG['install'][43]="Datubāze tika sagatavota"; 
$LANG['install'][47]="Nevaru izveidot datubāzes uzstādījumu datni"; 
$LANG['install'][48]="Kļūda veidojot datubāzi!"; 
$LANG['install'][49]="Jūs neizvēlējāties datubāzi!"; 
$LANG['install'][50]="Pārbaudu rakstīšanas tiesības sesiju datnēm"; 
$LANG['install'][52]="Pārbaudu rakstīšanas tiesības cron datnēm"; 
$LANG['install'][53]="Pārbauda žurnāla failu ierakstu"; 
$LANG['install'][55]="Instalācija ir pabeigta"; 
$LANG['install'][57]="Noklusētais lietotājvārds / parole ir:"; 
$LANG['install'][58]="glpi/glpi administratora kontam"; 
$LANG['install'][59]="tech/tech tehniķa kontam"; 
$LANG['install'][60]="normal/normal for the normal account"; 
$LANG['install'][61]="post-only/postonly for the postonly account"; 
$LANG['install'][62]="You can delete or modify these accounts as well as the initial data."; 
$LANG['install'][64]="Pieslēgties GLPI"; 
$LANG['install'][65]="magic_quotes_sybase paplašinājuma pārbaude"; 
$LANG['install'][66]="GLPI nevar korekti darboties ar ieslēgtu magic_quotes_sybase paplašinājumu; izslēdziet to un mēģiniet vēlreiz"; 
$LANG['install'][67]="magic_quotes_sybase opcija nav aktīva - lieliski!"; 
$LANG['install'][68]="Test session auto start"; 
$LANG['install'][69]="session.auto_start is activated. See .htaccess file in the GLPI root for more information."; 
$LANG['install'][70]="Nevaru izveidot datni ar datubāzes pieejas datiem, lūdzu pārbaudiet datņu pieejas tiesības."; 
$LANG['install'][71]="Mysql paplašinājuma pārbaude."; 
$LANG['install'][72]="PHP jābūt instalētam/kompilētam ar Mysql paplašinājumu."; 
$LANG['install'][73]="Funkcija mysql_query() eksistē - lieliski!"; 
$LANG['install'][74]="Pārbauda, vai tiek lietots Session_use_trans_sid parametrs"; 
$LANG['install'][75]="Jums php.ini datnē nepieciešams atslēgt Session_use_trans_id opciju"; 
$LANG['install'][76]="Sesijas darbojas (nav problēmu ar trans_id)- lieliski!"; 
$LANG['install'][77]="Solis"; 
$LANG['install'][81]="Instalācijas sākums"; 
$LANG['install'][82]="Datubāze izveidota"; 
$LANG['install'][85]="Nepieciešamās funkcijas darbojas - lielisli!"; 
$LANG['install'][86]="Pieejamās atmiņas tests"; 
$LANG['install'][87]="Piešķirta atmiņa:"; 
$LANG['install'][88]="Parasti GLPI ir nepieciešami vismaz 64MB atmiņas."; 
$LANG['install'][89]="Lieliski!"; 
$LANG['install'][90]="Mēģiniet php.ini palielināt memory_limit parametra vērtību."; 
$LANG['install'][91]="Piešķirtā atmiņa > 64M"; 
$LANG['install'][92]="Licence"; 
$LANG['install'][93]="Es izlasīju augstāk minēto licenci un piekrītu tai."; 
$LANG['install'][94]="Es izlasīju augstāk minēto licenci un nepiekrītu tai."; 
$LANG['install'][95]="Neierobežota atmiņa"; 
$LANG['install'][96]="Neierobežota atmiņa"; 
$LANG['install'][97]="Pārbaudiet mapes pieejas tiesības:"; 
$LANG['install'][99]="Pārbaudu rakstīšanas tiesības kešatmiņas datnēm"; 
$LANG['install'][100]="Mapīti izveidot nebija iespējams"; 
$LANG['install'][101]="Mapīte tika izveidota, taču to nav iespējams dzēst"; 
$LANG['install'][102]="Test json functions"; 
$LANG['install'][103]="GLPI can't work correctly without the json_encode and json_decode functions"; 
$LANG['install'][104]="mbstring extension test"; 
$LANG['install'][105]="Mbstring extension of your parser PHP is not installed"; 
$LANG['install'][106]="Checking write permissions for graphic files"; 

$LANG['job'][2]=""; 
$LANG['job'][4]="Iesniedzējs"; 
$LANG['job'][5]="Piešķirts"; 
$LANG['job'][6]="Tehniķis"; 
$LANG['job'][7]="Sekojums"; 
$LANG['job'][8]="last(s) ticket(s)"; 
$LANG['job'][9]="Follow-up"; 
$LANG['job'][11]="Aprakstiet problēmu/darbību"; 
$LANG['job'][12]="Šim pieteikumam nav sekojumu."; 
$LANG['job'][13]="New ticket"; 
$LANG['job'][15]="Solved"; 
$LANG['job'][19]="Nosūtīt sekojumus uz epastu"; 
$LANG['job'][20]="Atvēlētais laiks"; 
$LANG['job'][21]="Stunda(s)"; 
$LANG['job'][22]="Minūte(s)"; 
$LANG['job'][29]="Pievienot jaunu sekojumu"; 
$LANG['job'][30]="Pievienot jaunu sekojumu"; 
$LANG['job'][31]="Ilgums"; 
$LANG['job'][32]="Nav"; 
$LANG['job'][33]="Nav apraksta"; 
$LANG['job'][34]="Plan this task"; 
$LANG['job'][35]="Plānošana"; 
$LANG['job'][37]="Kopsavilkums"; 
$LANG['job'][38]="Pieteikums"; 
$LANG['job'][39]="Atjaunināt sekojumu"; 
$LANG['job'][40]="Maksa par laiku"; 
$LANG['job'][41]="Fiksētas izmaksas"; 
$LANG['job'][42]="Materiālu izmaksas"; 
$LANG['job'][43]="Kopējās izmaksas"; 
$LANG['job'][44]="Pieprasījuma avots"; 
$LANG['job'][45]="Source of follow-up"; 
$LANG['job'][46]="The ticket will be added in the entity"; 
$LANG['job'][47]="Costs"; 
$LANG['job'][48]="Type of solution"; 
$LANG['job'][49]="New task"; 
$LANG['job'][50]="No task for this ticket"; 
$LANG['job'][51]="Approval of the solution"; 
$LANG['job'][52]="Atjaunināt sekojumu"; 
$LANG['job'][53]="Deletion of a task"; 
$LANG['job'][54]="Without a reply, the ticket will be automatically closed after"; 

$LANG['joblist'][0]="Statuss"; 
$LANG['joblist'][1]="Tikai manus"; 
$LANG['joblist'][2]="Svarīgums"; 
$LANG['joblist'][3]="Personal + group(s)"; 
$LANG['joblist'][4]="Izpildītājs"; 
$LANG['joblist'][6]="Apraksts"; 
$LANG['joblist'][7]="Jauns pieteikums šim objektam..."; 
$LANG['joblist'][8]="Pieteikumi nav atrasti"; 
$LANG['joblist'][9]="Jauns"; 
$LANG['joblist'][10]="Slēgts (atrisināts)"; 
$LANG['joblist'][11]="Atvērts"; 
$LANG['joblist'][12]="Slēgts"; 
$LANG['joblist'][13]="Tickets to be processed"; 
$LANG['joblist'][14]="Solved on"; 
$LANG['joblist'][16]="Neviens pieteikums nav apstrādē."; 
$LANG['joblist'][17]="Slēgts (neatrisināts)"; 
$LANG['joblist'][18]="Apstrādā (piesaistīts)"; 
$LANG['joblist'][19]="Apstrādā (plānots)"; 
$LANG['joblist'][21]="Apstrādā"; 
$LANG['joblist'][26]="Gaida izpildi"; 
$LANG['joblist'][27]="Epasts sekojumam"; 
$LANG['joblist'][28]="Tickets on linked items"; 
$LANG['joblist'][29]="Urgency"; 
$LANG['joblist'][30]="Impact"; 
$LANG['joblist'][32]="Solved"; 
$LANG['joblist'][33]="Closed"; 
$LANG['joblist'][34]="Not solved"; 
$LANG['joblist'][35]="Not closed"; 
$LANG['joblist'][36]="Status value in database"; 

$LANG['jobresolution'][1]="Solution"; 
$LANG['jobresolution'][3]="Approved solution"; 
$LANG['jobresolution'][4]="Refused solution"; 
$LANG['jobresolution'][5]="If you reject the solution, you must specify a reason"; 

$LANG['knowbase'][1]="BUJ"; 
$LANG['knowbase'][5]="Put this item in the FAQ"; 
$LANG['knowbase'][6]="Izvēlieties ieraksta kategoriju:"; 
$LANG['knowbase'][7]="Dzēst ierakstu no BUJ"; 
$LANG['knowbase'][8]="Labot ierakstu"; 
$LANG['knowbase'][9]="Dzēst šo ierakstu"; 
$LANG['knowbase'][10]="This item is part of the FAQ"; 
$LANG['knowbase'][11]="This item is not part of the FAQ"; 
$LANG['knowbase'][12]="Galvenā mape"; 
$LANG['knowbase'][13]="Kategorijas nosaukums"; 
$LANG['knowbase'][14]="Temats"; 
$LANG['knowbase'][15]="Saturs"; 
$LANG['knowbase'][24]="Pieeja bieži uzdotiem jautājumiem"; 
$LANG['knowbase'][26]="Skatījumi"; 
$LANG['knowbase'][27]="On"; 
$LANG['knowbase'][29]="Jaunākie raksti"; 
$LANG['knowbase'][30]="Populārākie jautājumi"; 

$LANG['ldap'][0]="Lielapjoma lietotāju imports no LDAP"; 
$LANG['ldap'][1]="Sinhronizē jau importētos lietotājus"; 
$LANG['ldap'][2]="Importēt jaunus lietotājus"; 
$LANG['ldap'][3]="Nav lietotāju ko importēt"; 
$LANG['ldap'][4]="LDAP direktorijas izvēle"; 
$LANG['ldap'][5]="Izvēlieties LDAP direktoriju no kuras importēt lietotājus"; 
$LANG['ldap'][6]="Nav iespējams pieslēgties LDAP direktorijai"; 
$LANG['ldap'][7]="Nav definēta LDAP direktorija"; 
$LANG['ldap'][8]="Warning: The request exceeds the limit of the directory. The results are only partial."; 
$LANG['ldap'][9]="Pārbaudīt vai iespējams pieslēgties LDAP direktorijai"; 
$LANG['ldap'][12]="Sinhronizācija"; 
$LANG['ldap'][13]="in the LDAP directory"; 
$LANG['ldap'][14]="iekš GLPI"; 
$LANG['ldap'][15]="Sinhronizēt"; 
$LANG['ldap'][16]="Iepriekšēja pielāgošana"; 
$LANG['ldap'][17]="Active Directory"; 
$LANG['ldap'][18]="List of LDAP directory replicates"; 
$LANG['ldap'][19]="Kopēt"; 
$LANG['ldap'][20]="Pievienot LDAP direktorijas repliku"; 
$LANG['ldap'][21]="Galvenais serveris"; 
$LANG['ldap'][22]="Papildus"; 
$LANG['ldap'][23]="Lielapjoma grupu imports mo LDAP"; 
$LANG['ldap'][24]="Jaunu grupu imports"; 
$LANG['ldap'][25]="Nav grupu ko importēt"; 
$LANG['ldap'][30]="Aliasu apstrāde LDAP"; 
$LANG['ldap'][31]="Nesekot atsaucēm, pēc noklusējuma (Never dereferenced)"; 
$LANG['ldap'][32]="Vienmēr bez atsaucēm (always dereferenced)"; 
$LANG['ldap'][33]="Dereferenced during the search (but not when locating)"; 
$LANG['ldap'][34]="Dereferenced when locating (not during the search)"; 
$LANG['ldap'][35]="Import an user"; 
$LANG['ldap'][36]="No directory associated to entity : search impossible"; 
$LANG['ldap'][38]="Search criterias for users"; 
$LANG['ldap'][39]="Advanced"; 
$LANG['ldap'][40]="Simple"; 
$LANG['ldap'][41]="To change"; 
$LANG['ldap'][42]="No directory selected"; 
$LANG['ldap'][43]="No users to be synchronized"; 
$LANG['ldap'][44]="Noklusējuma serveris"; 
$LANG['ldap'][45]="Action when a user is deleted from the LDAP directory"; 
$LANG['ldap'][46]="Withdraw accreditations and groups (dynamics)"; 
$LANG['ldap'][47]="Put in trash"; 
$LANG['ldap'][48]="Deleted user in LDAP directory"; 
$LANG['ldap'][49]="View users added since"; 
$LANG['ldap'][50]="View users updated since"; 
$LANG['ldap'][52]="Less than"; 
$LANG['ldap'][53]="More than"; 
$LANG['ldap'][54]="Enable filtering by date"; 
$LANG['ldap'][55]="Disable filtering by date"; 
$LANG['ldap'][56]="Nedēļas"; 

$LANG['links'][1]="Saite vai datnes nosaukums"; 
$LANG['links'][4]="Saistītās aparatūras tips"; 
$LANG['links'][6]="Valid tags"; 
$LANG['links'][7]="Saite nav norādīta"; 
$LANG['links'][9]="Datnes saturs"; 

$LANG['log'][1]="sistēma"; 
$LANG['log'][16]="plānošana"; 
$LANG['log'][18]="sastāvdaļas"; 
$LANG['log'][20]="objekts pievienots"; 
$LANG['log'][21]="atjaunināt objektu"; 
$LANG['log'][22]="dzēst objektu"; 
$LANG['log'][23]="atjaunot objektu"; 
$LANG['log'][24]="atbrīvot objektu"; 
$LANG['log'][26]="atvienot objektu"; 
$LANG['log'][27]="objekta savienojums"; 
$LANG['log'][28]="atjaunināt sastāvdaļas"; 
$LANG['log'][29]="approval/refusal of the solution"; 
$LANG['log'][30]="pievienot tipu"; 
$LANG['log'][31]="dzēst tipu"; 
$LANG['log'][32]="tiek pievienota saite ar objektu"; 
$LANG['log'][33]="dzēst objektu saiti"; 
$LANG['log'][34]="pievienot piegādātāja saiti"; 
$LANG['log'][35]="dzēst piegādātāja saiti"; 
$LANG['log'][40]="IP savienojums"; 
$LANG['log'][41]="savienojums neizdevās"; 
$LANG['log'][42]="Rezervēšana"; 
$LANG['log'][44]="Virsraksts"; 
$LANG['log'][45]="Veiksmīga"; 
$LANG['log'][46]="Neizdevās"; 
$LANG['log'][48]="pievienot lietotāju grupai"; 
$LANG['log'][49]="izmest lietotāju no grupas"; 
$LANG['log'][55]="Savienojums"; 
$LANG['log'][59]="Automātiskās darbības"; 
$LANG['log'][60]="use unitary management for this item"; 
$LANG['log'][61]="pievienot lietotāju nodaļai"; 
$LANG['log'][62]="pilnībā dzēst lietotāju"; 
$LANG['log'][64]="modification of field"; 
$LANG['log'][65]="nosacījums"; 
$LANG['log'][66]="Drošība"; 
$LANG['log'][67]="piezīmju maiņa"; 
$LANG['log'][70]="pievienota tīkla ligzda"; 
$LANG['log'][71]="pievienotas vairākas tīkla ligzdas"; 
$LANG['log'][73]="dzēsta tīkla ligzda"; 
$LANG['log'][74]="dzēstas vairākas tīkla ligzdas"; 
$LANG['log'][75]="pārvietota tīkla ligzda"; 
$LANG['log'][77]="tīkla ligzdas pievienošana VLAN"; 
$LANG['log'][78]="tīkla ligzdu pievienošana VLAN"; 
$LANG['log'][79]="vlan dissociated from a network port"; 
$LANG['log'][80]="vairāku tīkla ligzdu atsaiste no VLAN"; 
$LANG['log'][82]="versijas pievienošana"; 
$LANG['log'][83]="modification of version"; 
$LANG['log'][84]="version's deletion"; 
$LANG['log'][85]="licences pievienošana"; 
$LANG['log'][86]="modification of licence"; 
$LANG['log'][87]="licence's deletion"; 
$LANG['log'][88]="kasetņu pievienošana"; 
$LANG['log'][89]="izlietojamo materiālu pievienošana"; 
$LANG['log'][90]="kasetnes izlaišana"; 
$LANG['log'][91]="deletion of a consumable"; 
$LANG['log'][92]="kasetnes restaurācija"; 
$LANG['log'][93]="restoration of a consumable"; 
$LANG['log'][94]="kasetņu atjaunināšana"; 
$LANG['log'][95]="kasetņu uzstādīšana"; 
$LANG['log'][96]="kasetņu noņemšana"; 
$LANG['log'][97]="consumable out for the user"; 
$LANG['log'][98]="add an element"; 
$LANG['log'][99]="modification of an item"; 
$LANG['log'][100]="deletion of an item"; 

$LANG['login'][0]="Pēdējā pieslēgšanās"; 
$LANG['login'][1]="Pieslēgties atkārtoti"; 
$LANG['login'][2]="LDAP directory"; 
$LANG['login'][3]="IMAP/POP"; 
$LANG['login'][4]="CAS"; 
$LANG['login'][5]="Pieeja liegta"; 
$LANG['login'][6]="Lietotājs"; 
$LANG['login'][7]="Parole"; 
$LANG['login'][8]="Nav norādīts lietotājvārds vai parole"; 
$LANG['login'][9]="Nav vēl atpazīts"; 
$LANG['login'][10]="Pieteikšanās"; 
$LANG['login'][11]="Lietotājam nav atļauts pieslēgties GLPI"; 
$LANG['login'][12]="Nepareizs lietotājvārds vai parole"; 
$LANG['login'][13]="Paroles lauks ir tukšs"; 
$LANG['login'][14]="nezināms lietotājs"; 
$LANG['login'][15]="Nav atrasts lietotājs vai arī atrasti vairāki"; 
$LANG['login'][16]="neveiksmīga pieslēgšanās izmantojot LDAP"; 
$LANG['login'][18]="GLPI iekšējā datubāze"; 
$LANG['login'][20]="Jums nav pieejas šai programmai - Jūsu lietotāja konts ir izslēgts vai dzēsts"; 
$LANG['login'][21]="Pārbaudīt savienojumu ar IMAP/POP serveri"; 
$LANG['login'][22]="Pārbaude veiksmīga"; 
$LANG['login'][23]="Pārbaude neveiksmīga"; 
$LANG['login'][24]="Pēdējās pieslēgšanās datums"; 
$LANG['login'][25]="Jums nav tiesību pieslēgties"; 
$LANG['login'][26]="Jūsu pārlūkprogrammai nepieciešams ieslēgt JavaScript atbalstu!"; 
$LANG['login'][27]="Jūsu pārlūkprogrammai jāpieņem cepumiņi lai varētu darboties ar šo programmu"; 
$LANG['login'][30]="Mainīt pieteikšanās veidu"; 
$LANG['login'][31]="Pieteikšanās izmantojot LDAP autorizāciju"; 
$LANG['login'][32]="Pieteikšanās izmantojot GLPI datubāzi"; 
$LANG['login'][33]="Pieteikšanās izmantojot IMAP/POP serveri"; 

$LANG['mailgate'][0]="Pasta vārteja"; 
$LANG['mailgate'][2]="Saņemt epasta pieteikumus tūlīt"; 
$LANG['mailgate'][3]="Pieejamo un saņemto epastu skaits"; 
$LANG['mailgate'][4]="mbstring paplašinājums nav atrasts. Var būt problēmas ar garumzīmēm, mīkstinājumiem."; 
$LANG['mailgate'][5]="Nederīga pievienotā datne"; 
$LANG['mailgate'][6]="Pievienotā datne ir par lielu"; 
$LANG['mailgate'][7]="Maximum size of each file imported by the mail receiver"; 
$LANG['mailgate'][9]="Your email could not be processed.\nIf the problem persists, contact the administrator"; 
$LANG['mailgate'][10]="Email refused"; 
$LANG['mailgate'][11]="Process of emails import"; 
$LANG['mailgate'][12]="Unable to affect the email to an entity"; 
$LANG['mailgate'][13]="Reason of rebuff"; 
$LANG['mailgate'][14]="Email not found. Impossible import"; 
$LANG['mailgate'][16]="Re:"; 

$LANG['mailing'][0]="----------------------------------------------------------"; 
$LANG['mailing'][1]="======================================================================"; 
$LANG['mailing'][4]="Izpildītie pieteikumu sekojumi"; 
$LANG['mailing'][5]="Problēmas apraksts"; 
$LANG['mailing'][10]="Jauns pieteikuma sekojums"; 
$LANG['mailing'][12]="Pieteikums piešķirts"; 
$LANG['mailing'][14]="Labota pieteikuma kategorija"; 
$LANG['mailing'][15]="Mainīta pieteikuma prioritāte"; 
$LANG['mailing'][17]="Mainīta pieteikuma ierīce\objekts"; 
$LANG['mailing'][18]="Mainīts pieteikuma autors"; 
$LANG['mailing'][19]="Jauna rezervācija"; 
$LANG['mailing'][20]="Mainīta pieteikuma grupa"; 
$LANG['mailing'][21]="Mainīts pieteikuma iesniedzējs"; 
$LANG['mailing'][23]="Rezervācijas izmaiņas"; 
$LANG['mailing'][26]="Pievienots dokuments:"; 
$LANG['mailing'][27]="Mainīts pieteikuma statuss"; 
$LANG['mailing'][29]="Rezervācija atcelta"; 
$LANG['mailing'][30]="Pieteikuma papildinājums"; 
$LANG['mailing'][31]="Šis ir testa epasts pasta sistēmas darbības pārbaudei"; 
$LANG['mailing'][32]="Pasta tests"; 
$LANG['mailing'][33]="Kasetņu trauksme"; 
$LANG['mailing'][35]="Brīdinājuma slieksnis sasniegts šādam izlietojamo materiālu tipam:"; 
$LANG['mailing'][36]="Izlietojamo materiālu trauksme"; 
$LANG['mailing'][37]="Līguma darbības beigas:"; 
$LANG['mailing'][39]="Brīdinājums par līgumu beigšanos"; 
$LANG['mailing'][40]="Objektam beigusies garantija:"; 
$LANG['mailing'][41]="Finansu informācijas brīdinājums"; 
$LANG['mailing'][42]="Mainīta stundas likme"; 
$LANG['mailing'][43]="Mainītas fiksētās izmaksas"; 
$LANG['mailing'][44]="Mainītas materiālu cenas"; 
$LANG['mailing'][45]="Mainīt darba virsrakstu"; 
$LANG['mailing'][46]="Mainīts problēmas apraksts"; 
$LANG['mailing'][47]="Kļūda sūtot epastu"; 
$LANG['mailing'][48]="Mainīts atvēršanas datums"; 
$LANG['mailing'][49]="Mainīts slēgšanas datums"; 
$LANG['mailing'][50]="Mainīts pieteikuma saņēmējs"; 
$LANG['mailing'][51]="Beigusies licence:"; 
$LANG['mailing'][53]="Change of solution"; 
$LANG['mailing'][54]="Expiry date"; 
$LANG['mailing'][100]="Kategorija nav definēta"; 
$LANG['mailing'][101]="Sekojumu sūtītšana uz epastu ir ieslēgta"; 
$LANG['mailing'][102]="Sekojumu sūtītšana uz epastu ir izslēgta"; 
$LANG['mailing'][104]="Papilddarba ilgums"; 
$LANG['mailing'][105]="Nav pieškirts"; 
$LANG['mailing'][107]="Nekas"; 
$LANG['mailing'][109]="Grupa nav norādīta"; 
$LANG['mailing'][110]="Nederīga epasta adrese"; 
$LANG['mailing'][113]="Notification templates"; 
$LANG['mailing'][114]="Body"; 
$LANG['mailing'][115]="Main part of email"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="teksts"; 
$LANG['mailing'][118]="E-pasts"; 
$LANG['mailing'][119]="Occurrence"; 
$LANG['mailing'][120]="Notification method"; 
$LANG['mailing'][121]="Recipients"; 
$LANG['mailing'][122]="Task(s) already done"; 
$LANG['mailing'][123]="Solved ticket"; 
$LANG['mailing'][124]="Add a new translation"; 
$LANG['mailing'][125]="Default translation"; 
$LANG['mailing'][126]="Template translation"; 
$LANG['mailing'][127]="Closing of the ticket"; 
$LANG['mailing'][128]="leave the field empty for a generation from HTML"; 
$LANG['mailing'][129]="Deletion of a ticket"; 
$LANG['mailing'][130]="No"; 
$LANG['mailing'][131]="Recipient"; 
$LANG['mailing'][132]="Email header"; 
$LANG['mailing'][133]="Dzēst e-pastu(s)"; 
$LANG['mailing'][134]="Updating follow-up"; 
$LANG['mailing'][135]="Follow-up's deletion"; 
$LANG['mailing'][136]="Reservation expired"; 
$LANG['mailing'][137]="Hardware user"; 
$LANG['mailing'][138]="List of available tags"; 
$LANG['mailing'][139]="Label"; 
$LANG['mailing'][140]="Tag"; 
$LANG['mailing'][141]="Followups"; 
$LANG['mailing'][142]="Sekojumi"; 
$LANG['mailing'][143]="Validations"; 
$LANG['mailing'][144]="Historical"; 
$LANG['mailing'][145]="List of values"; 
$LANG['mailing'][146]="Single value"; 
$LANG['mailing'][147]="Possible value(s)"; 

$LANG['Menu'][0]="Datori"; 
$LANG['Menu'][1]="Tīkli"; 
$LANG['Menu'][2]="Printeri"; 
$LANG['Menu'][3]="Monitori"; 
$LANG['Menu'][4]="Programmatūra"; 
$LANG['Menu'][5]="Tickets"; 
$LANG['Menu'][6]="Atskaites"; 
$LANG['Menu'][11]="Uzstādījumi"; 
$LANG['Menu'][12]="Maintenance"; 
$LANG['Menu'][13]="Statistika"; 
$LANG['Menu'][14]="Lietotāji"; 
$LANG['Menu'][15]="Administrēšana"; 
$LANG['Menu'][16]="Ierīces"; 
$LANG['Menu'][17]="Rezervācijas"; 
$LANG['Menu'][18]="Rīki"; 
$LANG['Menu'][19]="Knowledge base"; 
$LANG['Menu'][20]="BUJ"; 
$LANG['Menu'][21]="Kasetnes"; 
$LANG['Menu'][22]="Kontakti"; 
$LANG['Menu'][23]="Piegādātāji"; 
$LANG['Menu'][24]="Finansiālā informācija"; 
$LANG['Menu'][25]="Līgumi"; 
$LANG['Menu'][26]="Pārvaldība"; 
$LANG['Menu'][27]="Dokumenti"; 
$LANG['Menu'][28]="Statuss"; 
$LANG['Menu'][29]="Plānošana"; 
$LANG['Menu'][30]="Žurnāli"; 
$LANG['Menu'][31]="Simplified interface"; 
$LANG['Menu'][32]="Izlietojamie materiāli"; 
$LANG['Menu'][33]="OCSNG"; 
$LANG['Menu'][34]="Tālruņi"; 
$LANG['Menu'][35]="Profili"; 
$LANG['Menu'][36]="Grupas"; 
$LANG['Menu'][37]="Nodaļas"; 
$LANG['Menu'][38]="Inventārs"; 
$LANG['Menu'][39]="Receivers"; 
$LANG['Menu'][40]="Grāmatzīmes"; 
$LANG['Menu'][41]="Tiesības"; 

$LANG['monitors'][14]="Mikrofons"; 
$LANG['monitors'][15]="Skaļruņi"; 
$LANG['monitors'][18]="Karodziņi"; 
$LANG['monitors'][19]="Sub-D"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="Izmērs"; 
$LANG['monitors'][32]="DVI"; 
$LANG['monitors'][33]="Pivot funkcija"; 

$LANG['networking'][4]="Network port"; 
$LANG['networking'][5]="Memory (MB)"; 
$LANG['networking'][6]="Tīkla ligzda"; 
$LANG['networking'][13]="tīkla ligzdas atrastas"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="Savienots ar"; 
$LANG['networking'][19]="Pievienot tīkla ligzdu..."; 
$LANG['networking'][21]="Port number"; 
$LANG['networking'][25]="uz"; 
$LANG['networking'][37]="networking port(s) found"; 
$LANG['networking'][44]="Ligzda"; 
$LANG['networking'][46]="Pievienot vairākas tīkla ligzdas..."; 
$LANG['networking'][47]="No"; 
$LANG['networking'][48]="Ar"; 
$LANG['networking'][51]="Tīkla punkts"; 
$LANG['networking'][55]="Pievienot VLAN"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="Izvēlieties no saraksta vai ierakstiet MAC adresi"; 
$LANG['networking'][58]="Atvienot VLAN"; 
$LANG['networking'][59]="Vārteja"; 
$LANG['networking'][60]="Maska"; 
$LANG['networking'][61]="Subnets"; 

$LANG['ocsconfig'][1]="OCSNG database user"; 
$LANG['ocsconfig'][2]="Host for the OCSNG database"; 
$LANG['ocsconfig'][3]="OCSNG user password"; 
$LANG['ocsconfig'][4]="Name of the OCSNG database"; 
$LANG['ocsconfig'][5]="Importēšanas uzstādījumi"; 
$LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
$LANG['ocsconfig'][9]="Exclude the following tags (separator $, nothing for all)"; 
$LANG['ocsconfig'][10]="vispārējais imports (Global import)"; 
$LANG['ocsconfig'][11]="Neimportēt"; 
$LANG['ocsconfig'][12]="Vienību imports"; 
$LANG['ocsconfig'][13]="Vienību imports: viss tiek importēts 'kā-ir'"; 
$LANG['ocsconfig'][14]="Vispārējais imports: importēts tiek viss, bet materiāli tiek pārvaldīti vispārēji (bez atkārtošanās)"; 
$LANG['ocsconfig'][15]="Neimportēt: spraudnis neimportēs šos elementus"; 
$LANG['ocsconfig'][16]="Noklusētais stāvoklis"; 
$LANG['ocsconfig'][17]="Ierobežot norādīto tagu importu (atdalītājzīme $, nenorādiet neko, lai importētu visus)"; 
$LANG['ocsconfig'][18]="Vispirms pārliecinieties, vai OCSNG ir ieslēgta dublikātu meklēšana"; 
$LANG['ocsconfig'][19]="Vienību imports pēc sērijas numura (Unit import on serial number)"; 
$LANG['ocsconfig'][27]="Vispārējā informācija"; 
$LANG['ocsconfig'][36]="Modems"; 
$LANG['ocsconfig'][37]="Porti"; 
$LANG['ocsconfig'][38]="Use the OCSNG software dictionary"; 
$LANG['ocsconfig'][39]="OCSNG TAG"; 
$LANG['ocsconfig'][40]="Number of items to synchronize via the automatic OCSNG action"; 
$LANG['ocsconfig'][41]="Reģistrs"; 
$LANG['ocsconfig'][43]="OCSNG Administrative Information"; 
$LANG['ocsconfig'][48]="Uzvedība atslēdzot"; 
$LANG['ocsconfig'][49]="Miskaste"; 
$LANG['ocsconfig'][50]="Dzēšana"; 
$LANG['ocsconfig'][52]="Automātiska datoru savienojumu veidošana"; 
$LANG['ocsconfig'][53]="Ieslēgt automātisku savienošanu"; 
$LANG['ocsconfig'][54]="Existence criteria of a computer"; 
$LANG['ocsconfig'][55]="Find computers having the status"; 
$LANG['ocsconfig'][56]="tukšs"; 
$LANG['ocsconfig'][57]="vienāds"; 
$LANG['ocsconfig'][58]="The link automatically connects a GLPI computer with one in OCSNG.<br>This option is taken into account during manual link and by synchronization scripts."; 
$LANG['ocsconfig'][59]="Web address of the OCSNG console"; 

$LANG['ocsng'][0]="OCS Inventory NG"; 
$LANG['ocsng'][1]="Sinhronizēt jau importētos datorus"; 
$LANG['ocsng'][2]="Veikt jaunu datoru pievienošanu"; 
$LANG['ocsng'][3]="Dzēst savienojumus starp GLPI un OCSNG"; 
$LANG['ocsng'][4]="Savienot jaunus OCS datorus ar esošiem GLPI datoriem"; 
$LANG['ocsng'][5]="Veikt jaunu datoru pievienošanu"; 
$LANG['ocsng'][6]="Automātiska atjaunināšana"; 
$LANG['ocsng'][7]="Importēts no OCSNG"; 
$LANG['ocsng'][8]="Pievienošana veiksmīga"; 
$LANG['ocsng'][9]="No new computer to be imported"; 
$LANG['ocsng'][10]="Datori ar atjauninājumiem OCSNG datubāzē"; 
$LANG['ocsng'][11]="Atjaunināt datorus"; 
$LANG['ocsng'][12]="No new computer to be updated"; 
$LANG['ocsng'][13]="Importēt datus GLPI"; 
$LANG['ocsng'][14]="Last OCSNG inventory date"; 
$LANG['ocsng'][15]="Nav slēgtu lauku"; 
$LANG['ocsng'][16]="Slēgti lauki"; 
$LANG['ocsng'][18]="Pieslēgšanās OCSNG datubāzei veiksmīga"; 
$LANG['ocsng'][19]="Valid OCSNG configuration and version"; 
$LANG['ocsng'][20]="Invalid OCSNG Version: RC3 is required"; 
$LANG['ocsng'][21]="Neizdevās pieslēgties OCSNG datubāzei"; 
$LANG['ocsng'][22]="Uzmanību! Importētie dati pārrakstīs esošos datus (pārbaudiet konfigurāciju)"; 
$LANG['ocsng'][23]="Unable to import, GLPI computer is already related to an element of OCSNG"; 
$LANG['ocsng'][24]="Uzspiest sinhronizāciju"; 
$LANG['ocsng'][26]="OCSNG servera izvēle"; 
$LANG['ocsng'][27]="No OCSNG server defined"; 
$LANG['ocsng'][29]="OCSNG server"; 
$LANG['ocsng'][30]="Slēgts monitors(i)"; 
$LANG['ocsng'][32]="Slēgta ierīce(s)"; 
$LANG['ocsng'][34]="Slēgts prinetris(i)"; 
$LANG['ocsng'][36]="Piesaistāmā nodaļa"; 
$LANG['ocsng'][37]="Ieslēgt priekšskatījumu"; 
$LANG['ocsng'][38]="Izslēgt priekšapskati"; 
$LANG['ocsng'][40]="Match the rule ?"; 
$LANG['ocsng'][41]="Manuālais importēšanas režīms"; 
$LANG['ocsng'][42]="Invalid OCSNG configuration (TRACE_DELETED must be active)"; 
$LANG['ocsng'][43]="OCS datubāzei pieeja liegta (jābūt atļaujai rakstīt hardware.needed CHECKSUM)"; 
$LANG['ocsng'][44]="OCS datubāzei pieeja liegta (jābūt atļaujai dzēst deleted_equiv tabulā)"; 
$LANG['ocsng'][45]="OCS ID"; 
$LANG['ocsng'][46]="Dzēsts OCSNG datubāzē"; 
$LANG['ocsng'][47]="Linked with an OCSNG computer"; 
$LANG['ocsng'][48]="The OCSNG ID of the computer changed"; 
$LANG['ocsng'][49]="Aģents"; 
$LANG['ocsng'][50]="Slēgta(s) ip"; 
$LANG['ocsng'][52]="Slēgta programmatūra"; 
$LANG['ocsng'][54]="Software deleted by OCSNG synchronization"; 
$LANG['ocsng'][55]="Slēgts/i sējums/i"; 
$LANG['ocsng'][57]="OCSNG Interface"; 

$LANG['pager'][1]="līdz"; 
$LANG['pager'][2]=""; 
$LANG['pager'][3]="no"; 
$LANG['pager'][4]="Rādīt"; 
$LANG['pager'][5]="objekti"; 

$LANG['peripherals'][18]="Ražotājs"; 
$LANG['peripherals'][31]="Centralizēta pārvaldība"; 
$LANG['peripherals'][32]="Atsevišķa pārvaldība"; 
$LANG['peripherals'][33]="Pārvaldības tips"; 

$LANG['phones'][18]="Ražotājs"; 
$LANG['phones'][36]="Barošanas bloks"; 
$LANG['phones'][38]="Klausule"; 
$LANG['phones'][39]="Skaļrunis"; 
$LANG['phones'][40]="Līniju skaits"; 

$LANG['planning'][0]="Tehniķis norādītajā laikā jau ir aizņemts"; 
$LANG['planning'][1]="Klūda datumu ievadē. Sākuma datums nevar būt pēc beigu datuma"; 
$LANG['planning'][5]="Diena"; 
$LANG['planning'][6]="Nedēļa"; 
$LANG['planning'][8]="Sekošana"; 
$LANG['planning'][9]="Pievienoja"; 
$LANG['planning'][10]="Ical"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="Download the planning in Ical format"; 
$LANG['planning'][13]="webcal:// sinhronizācija"; 
$LANG['planning'][14]="Mēnesis"; 
$LANG['planning'][15]="Tavs plānojums"; 
$LANG['planning'][16]="Informācija"; 
$LANG['planning'][17]="Darāmais"; 
$LANG['planning'][18]="Paveikts"; 

$LANG['plugins'][0]="Plugins list"; 
$LANG['plugins'][2]="Installed / not configured"; 
$LANG['plugins'][3]="Installed / not activated"; 
$LANG['plugins'][4]="Error / to clean"; 
$LANG['plugins'][5]="Non-existent function(s)"; 
$LANG['plugins'][6]="Atjaunināt"; 
$LANG['plugins'][7]="No plugin installed"; 
$LANG['plugins'][8]="See the catalog of plugins"; 
$LANG['plugins'][9]="Authors"; 
$LANG['plugins'][10]="Incompatible plugin with this version of GLPI"; 

$LANG['printers'][14]="Seriālā"; 
$LANG['printers'][15]="Paralēlā"; 
$LANG['printers'][18]="Pieslēgvietas"; 
$LANG['printers'][27]="USB"; 
$LANG['printers'][28]="tīkls Ethernet"; 
$LANG['printers'][29]="Wifi"; 
$LANG['printers'][30]="Lapu skaitītāja sākotnējais rādījums"; 
$LANG['printers'][31]="Izdrukātās lapas"; 

$LANG['profiles'][0]="Globālās tiesības"; 
$LANG['profiles'][1]="Nodaļas tiesības"; 
$LANG['profiles'][2]="Profile's interface"; 
$LANG['profiles'][4]="Add a followup to tickets of associated group(s)"; 
$LANG['profiles'][5]="Izveidot pieteikumu"; 
$LANG['profiles'][6]="Pievienot sekojumu pieteikumiem (pieprasītājs)."; 
$LANG['profiles'][7]="Rādīt visus pieteikumus"; 
$LANG['profiles'][8]="View all follow-ups and tasks (public and private)"; 
$LANG['profiles'][9]="Show public followups and tasks"; 
$LANG['profiles'][10]="Lasīt"; 
$LANG['profiles'][11]="Rakstīt"; 
$LANG['profiles'][12]="Nav pieejas"; 
$LANG['profiles'][13]="Noklusētais profils"; 
$LANG['profiles'][14]="Dzēst pieteikumu"; 
$LANG['profiles'][15]="Pievienot sekojumus visiem pieteikumiem"; 
$LANG['profiles'][16]="Būt atbildīgajam par pieteikumu"; 
$LANG['profiles'][17]="Pārņemt pieteikumu"; 
$LANG['profiles'][18]="Papildināt pieteikumu"; 
$LANG['profiles'][19]="Piešķirt pieteikumu izpildei"; 
$LANG['profiles'][20]="Skatīt savu plānojumu"; 
$LANG['profiles'][21]="View all plannings"; 
$LANG['profiles'][22]="Profils"; 
$LANG['profiles'][23]="Rezervāciju Administrēšana"; 
$LANG['profiles'][24]="Mainīt paroli"; 
$LANG['profiles'][26]="Rādīt manas grupas(u) izveidotos pieteikumus"; 
$LANG['profiles'][27]="See hardware of my group(s)"; 
$LANG['profiles'][28]="Rekursīvs"; 
$LANG['profiles'][29]="Dinamisks"; 
$LANG['profiles'][30]="Skatīt OCSNG informāciju"; 
$LANG['profiles'][31]="Sinhronizēt OCSNG manuāli"; 
$LANG['profiles'][32]="Skatīt pieškirtos pieteikumus (savi + grupas)"; 
$LANG['profiles'][33]="Lietotājs nav atrasts"; 
$LANG['profiles'][34]="Uzraksts"; 
$LANG['profiles'][35]="Atjaunināt visus sekojumus"; 
$LANG['profiles'][36]="Skatīt manu kolēģu plānojumu"; 
$LANG['profiles'][37]="Noklusētā nodaļa"; 
$LANG['profiles'][38]="Redzamība"; 
$LANG['profiles'][39]="Piešķire (Assignment)"; 
$LANG['profiles'][40]="Atjaunināt"; 
$LANG['profiles'][41]="Veidošana"; 
$LANG['profiles'][42]="Asociācija (Asociēšana)"; 
$LANG['profiles'][43]="Lietotāju pieteikšanās un sinhronizācijas metodes"; 
$LANG['profiles'][44]="Change the priority"; 
$LANG['profiles'][45]="Add a task to all tickets"; 
$LANG['profiles'][46]="Edit all tasks"; 
$LANG['profiles'][47]="Add users from an external source"; 
$LANG['profiles'][48]="Create a validation request"; 
$LANG['profiles'][49]="Validate a ticket"; 

$LANG['registry'][1]="Strops (Hive)"; 
$LANG['registry'][2]="Ceļš"; 
$LANG['registry'][3]="Atslēga/vērtība"; 
$LANG['registry'][4]="Atrasta(s) reģistra atslēga(s)"; 
$LANG['registry'][5]="Atslēga reģistrā netika atrasta"; 
$LANG['registry'][6]="OCSNG name"; 

$LANG['reminder'][0]="Personīgās piezīmes"; 
$LANG['reminder'][1]="Publiskās piezīmes"; 
$LANG['reminder'][6]="Jauna piezīme"; 
$LANG['reminder'][9]="Teksts"; 
$LANG['reminder'][12]="Pievienot plānojumam"; 
$LANG['reminder'][15]="Bez virsraksta"; 
$LANG['reminder'][16]="Globālās piezīmes"; 

$LANG['reports'][0]="Izvēlies kādu atskaiti izveidot"; 
$LANG['reports'][4]="Aparatūras saraksts ar līgumiem"; 
$LANG['reports'][11]="Aparatūra ar līgumiem"; 
$LANG['reports'][12]="Aparatūras tips"; 
$LANG['reports'][13]="Datums(i)"; 
$LANG['reports'][15]="Rādīt atskaiti"; 
$LANG['reports'][19]="Alternatīvs lietotājvārds"; 
$LANG['reports'][26]="Noklusējuma atskaite"; 
$LANG['reports'][27]="Pēc līguma"; 
$LANG['reports'][28]="Pēc gada"; 
$LANG['reports'][33]="Tīkla atskaite"; 
$LANG['reports'][36]="Pievienotās ierīces"; 
$LANG['reports'][37]="Drops"; 
$LANG['reports'][38]="IP"; 
$LANG['reports'][39]="Pēc vietas"; 
$LANG['reports'][41]="Pēc aparatūras"; 
$LANG['reports'][42]="By drop"; 
$LANG['reports'][46]="koncentratora porti"; 
$LANG['reports'][47]="ierīces porti"; 
$LANG['reports'][49]="Network report by hardware"; 
$LANG['reports'][51]="Tīkla atskaite ('by drop')"; 
$LANG['reports'][52]="koncentrators (switch)"; 
$LANG['reports'][54]="Tīkla atskaite pēc vietas"; 
$LANG['reports'][57]="Materiālu saraksts"; 
$LANG['reports'][58]="Equipment's report by year"; 
$LANG['reports'][60]="Pieteikšanas datums"; 
$LANG['reports'][61]="Aizvēršanas datums"; 
$LANG['reports'][62]="Aparatūras finansu informācija"; 
$LANG['reports'][63]="Cita finansu informācija (licences, kasetnes, uc. )"; 
$LANG['reports'][64]="Resolution date"; 

$LANG['reservation'][1]="Rezervējamie objekti"; 
$LANG['reservation'][2]="Ierīce īslaicīgi nav pieejama"; 
$LANG['reservation'][3]="Make unavailable"; 
$LANG['reservation'][5]="Make available"; 
$LANG['reservation'][6]="Prohibit reservations"; 
$LANG['reservation'][7]="Atļaut nomu"; 
$LANG['reservation'][8]="Rezervēt"; 
$LANG['reservation'][9]="Rezervēt objektu"; 
$LANG['reservation'][16]="Kam"; 
$LANG['reservation'][17]="No"; 
$LANG['reservation'][18]="Izvēlētais objekts šajā laikā jau ir rezervēts"; 
$LANG['reservation'][20]="Atpakaļ uz plānojumu"; 
$LANG['reservation'][21]="See planning"; 
$LANG['reservation'][22]="Labot dokumentu"; 
$LANG['reservation'][25]="Visa nomājamā aparatūra"; 
$LANG['reservation'][27]="Rehearsal"; 
$LANG['reservation'][28]="Pēc nedēļas"; 
$LANG['reservation'][29]="Pēc dienas"; 
$LANG['reservation'][30]="reizes"; 
$LANG['reservation'][31]="Pēc"; 
$LANG['reservation'][35]="Nākotnes un esošās rezervācijas"; 
$LANG['reservation'][36]="Iepriekšējās rezervācijas"; 
$LANG['reservation'][37]="Rezervāciju nav"; 
$LANG['reservation'][38]="Tiešām vēlies dzēst šo objektu no nomājamo saraksta?"; 
$LANG['reservation'][39]="Visas aktuālās rezervācijas tiks noņemtas."; 
$LANG['reservation'][40]="Material reservations expiring today"; 

$LANG['rulesengine'][0]="ir"; 
$LANG['rulesengine'][1]="nav"; 
$LANG['rulesengine'][2]="satur"; 
$LANG['rulesengine'][3]="nesatur"; 
$LANG['rulesengine'][4]="sākas ar"; 
$LANG['rulesengine'][5]="finished by"; 
$LANG['rulesengine'][6]="Kritērijs"; 
$LANG['rulesengine'][7]="Darbības"; 
$LANG['rulesengine'][8]="Nosacījumu pārvaldīšana"; 
$LANG['rulesengine'][9]="Loģiskais operators"; 
$LANG['rulesengine'][10]="Position"; 
$LANG['rulesengine'][11]="Darbības tips"; 
$LANG['rulesengine'][12]="Lauki"; 
$LANG['rulesengine'][13]="Vērtība"; 
$LANG['rulesengine'][14]="Nosacījums"; 
$LANG['rulesengine'][15]="Iemesls"; 
$LANG['rulesengine'][16]="Kritērijs"; 
$LANG['rulesengine'][17]="Nosacījumi"; 
$LANG['rulesengine'][18]="Rules for assigning a computer to an entity"; 
$LANG['rulesengine'][19]="Nodaļu un tiesību piešķiršanas nosacījumi lietotājiem"; 
$LANG['rulesengine'][20]="Rules applied"; 
$LANG['rulesengine'][21]="Rules applicable in the sub-entities"; 
$LANG['rulesengine'][22]="Piešķirt"; 
$LANG['rulesengine'][23]="Local rules"; 
$LANG['rulesengine'][24]="Nosacījuma tips"; 
$LANG['rulesengine'][25]="Datora vārds"; 
$LANG['rulesengine'][26]="regular expression checks"; 
$LANG['rulesengine'][27]="regular expression does not match"; 
$LANG['rulesengine'][28]="'Business rules' pieteikumiem"; 
$LANG['rulesengine'][29]="Parādīt nosacījumu sarakstu"; 
$LANG['rulesengine'][30]="Darbība"; 
$LANG['rulesengine'][33]="Nolaižamo sarakstu vārdnīca"; 
$LANG['rulesengine'][35]="Programmatūras vārdnīca"; 
$LANG['rulesengine'][36]="Ražotāju vārdnīca"; 
$LANG['rulesengine'][37]="Nosacījumi kategorijas pievienošanai programmatūrai"; 
$LANG['rulesengine'][38]="Pārrēķināt"; 
$LANG['rulesengine'][40]="kategorija"; 
$LANG['rulesengine'][41]="Validācija"; 
$LANG['rulesengine'][42]="UN"; 
$LANG['rulesengine'][43]="VAI"; 
$LANG['rulesengine'][45]="Piešķirt vērtību no regex."; 
$LANG['rulesengine'][46]="Assign: equipment by IP address"; 
$LANG['rulesengine'][47]="Assign: equipment by name + domain"; 
$LANG['rulesengine'][48]="Assign equipment"; 
$LANG['rulesengine'][49]="Assign: equipment by MAC address"; 
$LANG['rulesengine'][50]="Datoru modeļu vārdnīca"; 
$LANG['rulesengine'][51]="Monitoru modeļu vārdnīca"; 
$LANG['rulesengine'][52]="Tālruņu modeļu vārdnīca"; 
$LANG['rulesengine'][53]="Perifērijas modeļu vārdnīca"; 
$LANG['rulesengine'][54]="Printeru modeļu vārdnīca"; 
$LANG['rulesengine'][55]="Tīklošanas modeļu vārdnīca"; 
$LANG['rulesengine'][56]="Modeļi"; 
$LANG['rulesengine'][60]="Datoru tipu vārdnīca"; 
$LANG['rulesengine'][61]="Monitoru tipu vārdnīca"; 
$LANG['rulesengine'][62]="Tālruņu tipu vārdnīca"; 
$LANG['rulesengine'][63]="Perifērijas tipu vārdnīca"; 
$LANG['rulesengine'][64]="Printeru tipu vārdnīca"; 
$LANG['rulesengine'][65]="Tīkla ierīču tipu vārdnīca"; 
$LANG['rulesengine'][66]="Tipi"; 
$LANG['rulesengine'][67]="Operating systems dictionary"; 
$LANG['rulesengine'][68]="Servispaku vārdnīca"; 
$LANG['rulesengine'][69]="OS versiju vārdnīca"; 
$LANG['rulesengine'][70]="Rules for assigning a ticket created through a mail receiver"; 
$LANG['rulesengine'][76]="Pielietot nosacījumus"; 
$LANG['rulesengine'][77]="Vārdnīcas"; 
$LANG['rulesengine'][78]="Versija"; 
$LANG['rulesengine'][79]="Pievienot rezultātu no regulārā atkārtojuma"; 
$LANG['rulesengine'][80]="Globālā vārdnīca"; 
$LANG['rulesengine'][81]="Nosacījuma rezultāts"; 
$LANG['rulesengine'][82]="Rezultāta detaļas"; 
$LANG['rulesengine'][83]="It is possible to affect the result of a regular expression using the string #0"; 
$LANG['rulesengine'][84]="Pārbaudīt nosacījumu izpildi"; 
$LANG['rulesengine'][85]="Result of the regular expression"; 
$LANG['rulesengine'][86]="Softwarecategory affected when software deleted by dictionary"; 
$LANG['rulesengine'][87]="Programmatūra izdzēsta ar GLPI vārdnīcu"; 
$LANG['rulesengine'][90]="Darbs tiek veikts..."; 
$LANG['rulesengine'][91]="Darbs pabeigts."; 
$LANG['rulesengine'][92]="Brīdinājums pirms vārdnīcu palaišanas"; 
$LANG['rulesengine'][93]="Warning! This operation can put software in the trash.<br>Sure to notify your users."; 
$LANG['rulesengine'][94]="FUSION"; 
$LANG['rulesengine'][95]="Ražotāja izvēle"; 
$LANG['rulesengine'][96]="Parādīt ražotāja(u) vārdnīcu<br> ( ----- = Visu)"; 
$LANG['rulesengine'][97]="Nav ko pārbaudīt"; 
$LANG['rulesengine'][100]="Kešatmiņas informācija"; 
$LANG['rulesengine'][102]="Nosacījuma nosaukums"; 
$LANG['rulesengine'][103]="Objekti kešatmiņā"; 
$LANG['rulesengine'][104]="Sākotnējā vērtība"; 
$LANG['rulesengine'][105]="Izmainīta vērtība"; 
$LANG['rulesengine'][106]="Bez izmaiņām"; 
$LANG['rulesengine'][107]="Neaktīvs"; 
$LANG['rulesengine'][108]="oriģināls"; 
$LANG['rulesengine'][110]="Tiesību piešķiršana"; 
$LANG['rulesengine'][111]="Nodaļu piešķiršana"; 
$LANG['rulesengine'][112]="Tiesību un nodaļu piešķiršana"; 
$LANG['rulesengine'][120]="Nosacījumu izpilde apstājās pēc pirmā nosacījuma."; 
$LANG['rulesengine'][121]="Visi nosacījumi tiek izpildīti."; 
$LANG['rulesengine'][122]="Nosacījumu izpildes rezutāts tiek nodots sekojošiem"; 
$LANG['rulesengine'][130]="Entity from LDAP"; 
$LANG['rulesengine'][131]="Entity from TAG"; 
$LANG['rulesengine'][132]="To be unaware of import"; 
$LANG['rulesengine'][133]="Entity from domain"; 
$LANG['rulesengine'][134]="Reject email (without email response)"; 
$LANG['rulesengine'][135]="Reject email (with email response)"; 
$LANG['rulesengine'][138]="LDAP criterias"; 
$LANG['rulesengine'][140]="Add a criterium"; 
$LANG['rulesengine'][142]="List of not imported emails"; 
$LANG['rulesengine'][144]="Entity based on user's profile"; 
$LANG['rulesengine'][145]="User with a single profile"; 
$LANG['rulesengine'][146]="User featuring the profile"; 
$LANG['rulesengine'][147]="User featuring a single profile"; 
$LANG['rulesengine'][148]="Mail domain is known"; 
$LANG['rulesengine'][150]="The rules linked with the entity have been disabled."; 

$LANG['search'][0]="Meklēt"; 
$LANG['search'][1]="for all"; 
$LANG['search'][2]="satur"; 
$LANG['search'][4]="sakārtots pēc"; 
$LANG['search'][8]="Sākuma datums"; 
$LANG['search'][9]="Beigu datums"; 
$LANG['search'][10]="kur meklēt:"; 
$LANG['search'][11]="Redzamajos objektos"; 
$LANG['search'][12]="Indicate an ended date"; 
$LANG['search'][15]="Nekas nav atrasts"; 
$LANG['search'][16]="Mazākais"; 
$LANG['search'][17]="Pievienot meklēšanas kritēriju"; 
$LANG['search'][18]="Dzēst meklēšanas kritēriju"; 
$LANG['search'][19]="Pievienot globālu meklēšanas kritēriju"; 
$LANG['search'][20]="Dzēst globālu meklēšanas kritēriju"; 

$LANG['setup'][0]="Izkrītošās izvēlnes"; 
$LANG['setup'][2]="Pievienot lietotāju..."; 
$LANG['setup'][3]="LDAP directory link"; 
$LANG['setup'][4]="Datoru tipi"; 
$LANG['setup'][5]="Operētājsistēmas"; 
$LANG['setup'][6]="Personalization"; 
$LANG['setup'][9]="Tīkla saskarnes"; 
$LANG['setup'][10]="Display order of surnames firstnames"; 
$LANG['setup'][14]="Email"; 
$LANG['setup'][18]="Login"; 
$LANG['setup'][19]="Password"; 
$LANG['setup'][20]="Password confirmation"; 
$LANG['setup'][21]="Error : the two passwords are not identical"; 
$LANG['setup'][35]="MHz"; 
$LANG['setup'][39]="Followed private for default"; 
$LANG['setup'][40]="Private tasks by default"; 
$LANG['setup'][41]="Izvēlēties valodu"; 
$LANG['setup'][42]="Tīklošanas tipi"; 
$LANG['setup'][43]="Printeru tipi"; 
$LANG['setup'][44]="Monitoru tipi"; 
$LANG['setup'][45]="Korpusa (case) tips"; 
$LANG['setup'][46]="Default value"; 
$LANG['setup'][47]="Default chart format"; 
$LANG['setup'][48]="Default values"; 
$LANG['setup'][62]="Izvēlēties kategoriju konfigurēšanai"; 
$LANG['setup'][63]="Uzmanību: jūs gatavojaties likvidēt viena vai vairāku ierakstu virsrakstus"; 
$LANG['setup'][64]="If you confirm the deletion the items using this heading used fields will be blanked"; 
$LANG['setup'][65]="Jūs varat nomainīt šī virsraksta visus paziņojumus ar citu:"; 
$LANG['setup'][67]="Ārējās autentifikācijas"; 
$LANG['setup'][69]="Ierīču tipi"; 
$LANG['setup'][70]="Vispārējie uzstādījumi"; 
$LANG['setup'][71]="Firmware"; 
$LANG['setup'][73]="Tīkla vieta"; 
$LANG['setup'][74]="Tu nevari izdzēst šo vietu, jo tā nav tukša (apakšvietas!)"; 
$LANG['setup'][75]="Kā apakšlīmenis"; 
$LANG['setup'][79]="Pieteikumu kategorijas"; 
$LANG['setup'][80]="Trešās personas tips."; 
$LANG['setup'][81]="Dokumentu virsraksti"; 
$LANG['setup'][82]="Kontakta tips"; 
$LANG['setup'][83]="Ieraksta statuss"; 
$LANG['setup'][84]="Kasetnes tips"; 
$LANG['setup'][85]="Līguma tips"; 
$LANG['setup'][86]="Type of memory"; 
$LANG['setup'][87]="Knowledge base categories"; 
$LANG['setup'][88]="Tīkls"; 
$LANG['setup'][89]="Domēns"; 
$LANG['setup'][90]="VLANi"; 
$LANG['setup'][91]="Datoru modeļi"; 
$LANG['setup'][92]="Izlietojamo materiālu tips"; 
$LANG['setup'][93]="Cieto disku saskarnes"; 
$LANG['setup'][94]="Monitoru modeļi"; 
$LANG['setup'][95]="Tīklošanas modeļi"; 
$LANG['setup'][96]="Printeru modeļi"; 
$LANG['setup'][97]="Perifērijas modeļi"; 
$LANG['setup'][98]="Tasks category"; 
$LANG['setup'][99]="Building number"; 
$LANG['setup'][100]="Telpas numurs"; 
$LANG['setup'][101]="Maximal number of automatic actions (run by CLI)"; 
$LANG['setup'][102]="Žurnalēšanas līmenis"; 
$LANG['setup'][103]="1- Kritisks (tikai neveiksmīgas pieslēgšanās)"; 
$LANG['setup'][104]="2- Nopietns (netiek izmantots)"; 
$LANG['setup'][105]="3- Svarīgi (veiksmīgās pieslēgšanās)"; 
$LANG['setup'][106]="4- Paziņojumi (pievienots, dzēsts, sekošana)"; 
$LANG['setup'][107]="5- Pilnīgs (Visu)"; 
$LANG['setup'][109]="How long system logs are keep in database (in days, 0 for infinite)"; 
$LANG['setup'][110]="Pieslēdzoties rādīt jaunos pieteikumus"; 
$LANG['setup'][111]="Maximum number of search results to display on a page"; 
$LANG['setup'][112]="Maximum number of characters for each items in dropdowns"; 
$LANG['setup'][113]="Noklusētā valoda"; 
$LANG['setup'][114]="Prioritātes krāsas"; 
$LANG['setup'][115]="Noklusētais brīdinājuma slieksnis kasetnēm un izlietojamajiem materiāliem"; 
$LANG['setup'][116]="Automātiski pievienot pieteikumu par aparatūru atbildīgajam tehniķim"; 
$LANG['setup'][117]="Ļaut anonīmiem lietotājiem skatīt BUJ"; 
$LANG['setup'][118]="Text on the login page"; 
$LANG['setup'][119]="Ekrāna uzstādījumi"; 
$LANG['setup'][120]="Use dynamic display for dropdowns and text fields"; 
$LANG['setup'][121]="Character to force the full display of dropdowns (wildcard)"; 
$LANG['setup'][122]="Maximum number of items to display in the dropdowns when wildcard is not used"; 
$LANG['setup'][123]="Don't use dynamic display if the number of items is less than"; 
$LANG['setup'][124]="Automātiski pievienot lietotājus no ārējā autentifikācijas avota"; 
$LANG['setup'][125]="... No ārēja avota"; 
$LANG['setup'][126]="Automātiski pievienot lietotāju no ārēja avota"; 
$LANG['setup'][127]="Ajax teksta lauku autopabeigšana"; 
$LANG['setup'][128]="Datuma formāts"; 
$LANG['setup'][129]="Show GLPI ID"; 
$LANG['setup'][130]="Number of days this action logs are stored"; 
$LANG['setup'][132]="Rādīt pilnu vārdu izkrītošajā izvēlnē"; 
$LANG['setup'][133]="Ieslēgt savienojumu ar OCSNG"; 
$LANG['setup'][134]="OCSNG režīms"; 
$LANG['setup'][135]="Normāls"; 
$LANG['setup'][136]="Tulkojums"; 
$LANG['setup'][137]="Debug"; 
$LANG['setup'][138]="Lietot GLPI režīmā"; 
$LANG['setup'][139]="Parasts"; 
$LANG['setup'][140]="Tipi"; 
$LANG['setup'][145]="Os"; 
$LANG['setup'][147]="Dynamic display"; 
$LANG['setup'][148]="Stundu solis"; 
$LANG['setup'][149]="Zīmju skaits aiz komata"; 
$LANG['setup'][150]="Skaitļu formāts"; 
$LANG['setup'][154]="Basedn"; 
$LANG['setup'][155]="rootdn (ne-anonīmiem pieslēgumiem)"; 
$LANG['setup'][156]="Parole (ne-anonīmiem pieslēgumiem)"; 
$LANG['setup'][157]="Jūsu PHP parserim nav instalēts PHP paplašinājums"; 
$LANG['setup'][158]="Nav iespējams lietot LDAP kā ārējo savienojuma avotu"; 
$LANG['setup'][159]="Savienojumu filtrs"; 
$LANG['setup'][162]="IMAP/POP konfigurācija"; 
$LANG['setup'][164]="IMAP/POP Hosta Vārds <br>(lietotāja e-pasts būs logins@šisserveris)"; 
$LANG['setup'][165]="Jūsu PHP parseris ir kompilēts bez IMAP funkcijām"; 
$LANG['setup'][166]="Nav iespējams lietot IMAP/POP kā ārējo savienojuma avotu"; 
$LANG['setup'][167]="LDAP directory / GLPI links"; 
$LANG['setup'][168]="Savienojuma uzstādījumi"; 
$LANG['setup'][169]="E-pasta mapīte (nav obligāti, parasti INBOX)"; 
$LANG['setup'][170]="Pieslēgšanās parametri"; 
$LANG['setup'][171]="Ports (neobligāts)"; 
$LANG['setup'][172]="Port (default=389)"; 
$LANG['setup'][174]="CAS hostdators"; 
$LANG['setup'][175]="Ports"; 
$LANG['setup'][176]="Saknes mape (neobligāts)"; 
$LANG['setup'][177]="CAS konfigurācija"; 
$LANG['setup'][178]="Jūsu PHP parserim nav instalēts CURL vai DOMXML paplašinājums"; 
$LANG['setup'][179]="Nav iespējams lietot CAS kā ārējo savienojuma avotu"; 
$LANG['setup'][180]="Izmantot TLS"; 
$LANG['setup'][181]="ldap_start_tls neeksistē"; 
$LANG['setup'][182]="Logout fallback URL"; 
$LANG['setup'][185]="Logs in files (SQL, email, automatic action...)"; 
$LANG['setup'][186]="Laika zona"; 
$LANG['setup'][190]="x509 sertifikāts"; 
$LANG['setup'][191]="x509 pasta atribūts"; 
$LANG['setup'][192]="Ieslēgts"; 
$LANG['setup'][193]="Datubāzes lauks, kurā glabājas lietotājvārds priekš pieslēgšanās _SERVER masīvam"; 
$LANG['setup'][194]="Papildus informācijas saņemšana no LDAP direktorijas"; 
$LANG['setup'][195]="Saglabāt statusu"; 
$LANG['setup'][196]="Clear status"; 
$LANG['setup'][197]="Kopēt datora statusu"; 
$LANG['setup'][198]="Uzstādīt statusu"; 
$LANG['setup'][199]="Remove the domain of login in form login@domain"; 
$LANG['setup'][200]="Infinite"; 
$LANG['setup'][201]="Alert and email followups configuration"; 
$LANG['setup'][202]="Enable Follow-up via email"; 
$LANG['setup'][203]="Administratora e-pasts"; 
$LANG['setup'][204]="E-pasta paraksts"; 
$LANG['setup'][205]="E-pasts nosūtīts administratoram"; 
$LANG['setup'][206]="Neizdevās nosūtīt e-pastu administrātoram"; 
$LANG['setup'][207]="Administratora reply-to epasts (ja nepieciešams)"; 
$LANG['setup'][217]="Jūsu sistēmai nav vai nav aktivēta PHP pasta funkcija"; 
$LANG['setup'][218]="SMTP izmantošana ir nepieciešama"; 
$LANG['setup'][219]="Ļaut anonīmu pieteikumu pievienošanu (helpdesk.receiver)"; 
$LANG['setup'][221]="Fiskālā gada sākums (gads un mēnesis)"; 
$LANG['setup'][223]="Ierobežot plānojumu"; 
$LANG['setup'][227]="URL of the application"; 
$LANG['setup'][228]="Login Field"; 
$LANG['setup'][229]="Send a test email to the administrator"; 
$LANG['setup'][231]="Use a SMTP server to send emails"; 
$LANG['setup'][232]="SMTP Host"; 
$LANG['setup'][234]="SMTP Login (optional)"; 
$LANG['setup'][235]="SMTP Password (optional)"; 
$LANG['setup'][236]="Iepriekšējais par pieteikumu atbildīgais tehniķis"; 
$LANG['setup'][237]="Administrators"; 
$LANG['setup'][239]="Par pieteikumu atbildīgais tehniķis"; 
$LANG['setup'][240]="Paziņošanas opcijas"; 
$LANG['setup'][241]="Nav personīgo uzstādījumu. Izveidot?"; 
$LANG['setup'][242]="Brīdinājumu uzstādījumi"; 
$LANG['setup'][243]="Izlietojamo materiālu brīdinājumi"; 
$LANG['setup'][244]="Kasetņu brīdinājumi"; 
$LANG['setup'][245]="Reminders frequency"; 
$LANG['setup'][246]="Līgumu brīdinājumi"; 
$LANG['setup'][247]="Finansiālās informācijas brīdinājumi"; 
$LANG['setup'][248]="Par pieteikumu atbildīgā grupa"; 
$LANG['setup'][249]="Pieprasītāja grupa"; 
$LANG['setup'][250]="Noklusētais meklēšanas lauku saraksts"; 
$LANG['setup'][252]="Izvēlēties pēc noklusējuma rādāmos ierakstus"; 
$LANG['setup'][253]="Filtrs meklēšanai grupās"; 
$LANG['setup'][254]="Meklēšanas tips"; 
$LANG['setup'][255]="Lietotājus saturošie grupu atriubūti"; 
$LANG['setup'][256]="Lietotājos"; 
$LANG['setup'][257]="Grupās"; 
$LANG['setup'][258]="Lietotāji un grupas"; 
$LANG['setup'][259]="Piederība grupai"; 
$LANG['setup'][260]="Grupas saturošais lietotāju atribūts"; 
$LANG['setup'][261]="Grupas DN"; 
$LANG['setup'][262]="Meklēšanai izmantot DN"; 
$LANG['setup'][263]="Meklēšanas filtrs lietotājiem"; 
$LANG['setup'][264]="Licenšu beigšanās brīdinājumi"; 
$LANG['setup'][271]="Ierobežot monitoru pārvaldīšanu"; 
$LANG['setup'][272]="Ierobežot ierīces pārvaldību"; 
$LANG['setup'][273]="Ierobežot tālruņu pārvaldīšanu"; 
$LANG['setup'][274]="manuālai pievienošanai"; 
$LANG['setup'][275]="Ierobežot printeru pārvaldīšanu"; 
$LANG['setup'][280]="Automātiski atjaunināt ar datoriem saistītos elementus"; 
$LANG['setup'][281]="When connecting or updating"; 
$LANG['setup'][282]="When disconnecting"; 
$LANG['setup'][283]="Kopēt"; 
$LANG['setup'][284]="Notīrīt"; 
$LANG['setup'][285]="Do not copy"; 
$LANG['setup'][286]="Do not delete"; 
$LANG['setup'][300]="Pārbaudīt, vai ir pieejama jauna versija"; 
$LANG['setup'][301]="Ir pieejama jauna versija:"; 
$LANG['setup'][302]="You will find it on the GLPI-PROJECT.org site"; 
$LANG['setup'][303]="Jums ir jaunākā pieejamā versija"; 
$LANG['setup'][304]="Savienojums neizdevās. Ja lietojiet starpniekserveri, lūdzu veiciet tā regulēšanu."; 
$LANG['setup'][305]="Every day"; 
$LANG['setup'][306]="Pārbaudīt vai nav pieejami atjauninājumi"; 
$LANG['setup'][307]="Nekad"; 
$LANG['setup'][308]="Katru nedēļu"; 
$LANG['setup'][309]="Katru mēnesi"; 
$LANG['setup'][310]="Vietnei nav iespējams pieslēgties"; 
$LANG['setup'][311]="Neizdevās pieslēgties starpniekserverim."; 
$LANG['setup'][312]="Tīmekļa vietnē nav datu"; 
$LANG['setup'][313]="Be careful : there is no default value"; 
$LANG['setup'][350]="Ļaut sasaistīt pieteikumu ar šādu aparatūru"; 
$LANG['setup'][351]="Visi ieraksti"; 
$LANG['setup'][352]="Pieteikumam piesaistāmi objekti"; 
$LANG['setup'][360]="Automātiskie lauki (atzīmēti ar *)"; 
$LANG['setup'][400]="Proxy configuration"; 
$LANG['setup'][407]="Simplified interface help link"; 
$LANG['setup'][408]="Standard interface help link"; 
$LANG['setup'][409]="Noklusētais virsraksts pievienojot dokumentu pieteikumam"; 
$LANG['setup'][503]="Tālruņu modeļi"; 
$LANG['setup'][504]="Tālruņu tipi"; 
$LANG['setup'][505]="Tālruņu barošanas bloku tipi"; 
$LANG['setup'][601]="LDAP vērtība"; 
$LANG['setup'][602]="Connection to OCSNG database"; 
$LANG['setup'][603]="Pievienot lietotāju"; 
$LANG['setup'][604]="Asociēt ar grupu"; 
$LANG['setup'][606]="Neizdevās pievienot. Lietotājs jau eksistē."; 
$LANG['setup'][607]="Piesaistīt profilam"; 
$LANG['setup'][608]="Software associable to a ticket by default"; 
$LANG['setup'][609]="Unable to add. The OCSNG server already exists."; 
$LANG['setup'][610]="Obligātāis pieteikuma virsraksts"; 
$LANG['setup'][611]="Obligātais pieteikuma saturs"; 
$LANG['setup'][612]="Obligātā pieteikuma kategorija"; 
$LANG['setup'][613]="Add a user who have no accreditation from a LDAP directory"; 
$LANG['setup'][614]="Unable to update login. A user already exists."; 
$LANG['setup'][615]="Life cycle of tickets"; 
$LANG['setup'][616]="From \ To"; 
$LANG['setup'][620]="Saite"; 
$LANG['setup'][621]="Search filter for entities"; 
$LANG['setup'][622]="Attribute representing entity"; 
$LANG['setup'][623]="Import entities from LDAP directory"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="SMTP"; 
$LANG['setup'][652]="SMTP+SSL"; 
$LANG['setup'][653]="SMTP+TLS"; 
$LANG['setup'][660]="Mail server"; 
$LANG['setup'][661]="Impossible to configure the notifications : please enable email monitoring"; 
$LANG['setup'][703]="Vispārēji"; 
$LANG['setup'][704]="Paziņojumi"; 
$LANG['setup'][707]="Alerts on reservations"; 
$LANG['setup'][708]="Alerts on tickets which are not solved since"; 
$LANG['setup'][720]="System informations"; 
$LANG['setup'][721]="Information about system installation and configuration"; 
$LANG['setup'][722]="To copy/paste in your support request"; 
$LANG['setup'][731]="Value of the global configuration"; 
$LANG['setup'][732]="Domain of electronic mail service"; 
$LANG['setup'][800]="MySQL replikācija"; 
$LANG['setup'][801]="Enable the MySQL replicate"; 
$LANG['setup'][802]="Datubāze"; 
$LANG['setup'][803]="Atšķirība starp galveno (master) un padoto (slave)"; 
$LANG['setup'][806]="Max delay between master and slave (minutes)"; 
$LANG['setup'][807]="The slave base is desynchronized. The difference is of:"; 
$LANG['setup'][808]="Pakļautās datubāze nav sinhronizēta!"; 
$LANG['setup'][809]="MYSQL replica: tikai lasāma"; 
$LANG['setup'][810]="Desynchronization MySQL replication"; 

$LANG['software'][1]="Purchase version"; 
$LANG['software'][2]="Version in use"; 
$LANG['software'][3]="Not installed affected licenses"; 
$LANG['software'][4]="Unlimited"; 
$LANG['software'][5]="Versijas"; 
$LANG['software'][6]="Publisher"; 
$LANG['software'][7]="Pievienot versiju"; 
$LANG['software'][8]="Pievienot licenci"; 
$LANG['software'][11]="Licences"; 
$LANG['software'][17]="Uzstādītā programmatūra"; 
$LANG['software'][19]="Instalācijas"; 
$LANG['software'][20]="Atlikušas"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="Jaunināt"; 
$LANG['software'][30]="Type of license"; 
$LANG['software'][32]="Beidzas derīgums"; 
$LANG['software'][44]="Uzstādīt programmatūru"; 
$LANG['software'][45]="Noinstalēt programmatūru"; 
$LANG['software'][46]="Piesaistāms pieteikumam"; 
$LANG['software'][47]="Merging"; 
$LANG['software'][48]="Apvienot"; 
$LANG['software'][49]="Software deleted after merging"; 
$LANG['software'][50]="Assigned to the computer"; 
$LANG['software'][51]="The number must be 1 to be able to affect"; 

$LANG['softwarecategories'][2]="Uncategorized software"; 
$LANG['softwarecategories'][3]="Unfold the software without category"; 
$LANG['softwarecategories'][4]="Unfold the software belonging to a category"; 
$LANG['softwarecategories'][5]="Programmatūras kategorija"; 

$LANG['state'][0]="Statuss"; 
$LANG['state'][6]="Ieraksta tips"; 
$LANG['state'][7]="Nekas nav atrasts"; 
$LANG['state'][11]="Kopsavilkums"; 

$LANG['stats'][0]="Izvēlies, kādu statistiku rādīt"; 
$LANG['stats'][1]="Globāli"; 
$LANG['stats'][2]="No item to display"; 
$LANG['stats'][3]="Pēc objekta"; 
$LANG['stats'][5]="Number of opened tickets"; 
$LANG['stats'][6]="Vidēja aizture pirms apstrādes uzsākšanas"; 
$LANG['stats'][7]="Show graphics"; 
$LANG['stats'][11]="Atrisināto pieteikumu skaits"; 
$LANG['stats'][13]="Pieteikumu skaits"; 
$LANG['stats'][15]="Vidēja aizture pirms apstrādes uzsākšanas"; 
$LANG['stats'][16]="Tehniķa vārds"; 
$LANG['stats'][20]="Lietotājvārds"; 
$LANG['stats'][23]="Statistika nav pieejama"; 
$LANG['stats'][25]="Vidējais (reālais) pieteikuma apstrādes ilgums"; 
$LANG['stats'][27]="Kopējais(reālais) pieteikuma apstrādes ilgums"; 
$LANG['stats'][30]="Laiks līdz darba sākšanai (vidēji)"; 
$LANG['stats'][31]="Diena(s)"; 
$LANG['stats'][33]="Minūte(s)"; 
$LANG['stats'][34]="Sekunde(s)"; 
$LANG['stats'][35]="Pieteikums(i)"; 
$LANG['stats'][44]="Piegādātāja nosaukums"; 
$LANG['stats'][45]="Pēc aparatūras"; 
$LANG['stats'][47]="Pēc pieteikumiem"; 
$LANG['stats'][48]="(piesaistīts)"; 
$LANG['stats'][49]="(sekojumi)"; 

$LANG['title'][5]="Zināšanu datubāze"; 
$LANG['title'][6]="Tīklošana"; 
$LANG['title'][9]="Objekta statuss"; 
$LANG['title'][10]="Pieteikuma sekojums"; 
$LANG['title'][13]="Lietotāja informācija"; 
$LANG['title'][14]="Ārējie autentificēšanās avoti"; 
$LANG['title'][24]="Atbalsts"; 
$LANG['title'][26]="Galvenais"; 
$LANG['title'][27]="Savienojumi"; 
$LANG['title'][28]="Pieteikumi"; 
$LANG['title'][30]="Komponentes"; 
$LANG['title'][33]="Ārējie linki"; 
$LANG['title'][34]="Linki"; 
$LANG['title'][37]="Piezīmes"; 
$LANG['title'][38]="Vēsturiskie"; 
$LANG['title'][40]="Publiskās un Privātās piezīmes"; 
$LANG['title'][42]="Liela apjoma modifikācija"; 
$LANG['title'][43]="Reģistrs"; 

$LANG['tracking'][1]="Manas ierīces"; 
$LANG['tracking'][2]="Veikt meklēšanu"; 
$LANG['tracking'][3]="Nepareizi datumi, jaunināšana atcelta"; 
$LANG['tracking'][4]="There is no urgency in your ticket, please correct."; 
$LANG['tracking'][8]="Nav problēmas apraksta pieteikumam, mēģini vēlreiz."; 
$LANG['tracking'][9]="Default for tickets"; 
$LANG['tracking'][10]="Default for mail recipients"; 
$LANG['tracking'][24]="Dokumentēt pieteikumu"; 
$LANG['tracking'][29]="Skaits"; 
$LANG['tracking'][30]="Jauns"; 
$LANG['tracking'][31]="Apstrādē (piešķirtie)"; 
$LANG['tracking'][32]="Apstrādē (plānotie)"; 
$LANG['tracking'][34]="Tieši"; 
$LANG['tracking'][35]="Rakstisks (Ierakstīts)"; 
$LANG['tracking'][37]="Saglabāt pieteikumus pēc aparatūras norakstīšanas"; 
$LANG['tracking'][38]="E-pasts tika nosūtīts uz"; 
$LANG['tracking'][39]="Visible in the simplified interface"; 

$LANG['transfer'][1]="Pārcelšana"; 
$LANG['transfer'][3]="Ja nav izmantots"; 
$LANG['transfer'][4]="Lai dzēstu pārsūtāmo elementu sarakstu"; 
$LANG['transfer'][5]="Tu vari turpināt pievienot elementus pārsūtīšanai vai pārsūtīt tos kas ir"; 
$LANG['transfer'][6]="Padomā par datu rezerves kopiju izveidošanu pirms pārsūtīšanas veikšanas"; 
$LANG['transfer'][7]="Objekti pārsūtīšanai"; 
$LANG['transfer'][8]="Pārsūtīšanas režīms"; 

$LANG['update'][88]="The version of the database is not compatible with the version of the installed files. An update is necessary."; 
$LANG['update'][89]="You are trying to use GLPI with files from an earlier version to the version of the database. Please install the files corresponding to the version of your database."; 
$LANG['update'][90]="Kļūda veicot datubāzes atjaunināšanu"; 
$LANG['update'][91]="Uzmanību!"; 
$LANG['update'][92]="Tu atjaunināsi GLPI datubāzi:"; 
$LANG['update'][93]="Veiksmīga pieslēgšanās datubāzei"; 
$LANG['update'][94]="Datubāzes atjaunināšana veiksmīgi pabeigta"; 
$LANG['update'][95]="Pieslēgšanās datubāzei neizdevās, pārbaudi konekcijas parametrus config_db.php failā"; 
$LANG['update'][96]="Tagad visi administrātori ir ar 'super-admin' tiesībām. Šis jaunais lietotāju tips arī tika pievienots."; 
$LANG['update'][105]="Neiespējami pabeigt atjaunināšanu šādā veidā!!"; 
$LANG['update'][106]="Atgriezties GLPI"; 
$LANG['update'][107]="Tagad Tev jāturpina atjaunināt datubāzes saturu"; 
$LANG['update'][130]="Lokāciju Atjaunināšana"; 
$LANG['update'][131]="Jaunā struktūra ir hierarhiska"; 
$LANG['update'][132]="Ja Tu lieto atdalošo simbolu, vari to izmantot lai automatizētu jaunās hierarhijas ģenerēšanu."; 
$LANG['update'][133]="Tu vari norādīt arī saknes vietu, kurā ietilps arī visas ģenerētās vietas."; 
$LANG['update'][134]="Norobežojošais atdalītājs"; 
$LANG['update'][135]="Root lokācija"; 
$LANG['update'][136]="Šī ir jaunā hierarhija. Ja piekrītat, varat apstiprināt."; 
$LANG['update'][137]="Jauna hierarhija"; 
$LANG['update'][138]="Faktiskā vieta"; 
$LANG['update'][139]="Optimizing tables"; 
$LANG['update'][140]="Creating indexes"; 
$LANG['update'][141]="Change of the database layout"; 
$LANG['update'][142]="Data migration"; 

$LANG['users'][1]="Title"; 
$LANG['users'][2]="Kategorija"; 

$LANG['validation'][0]="Apstiprinājums"; 
$LANG['validation'][1]="Send a Approval request"; 
$LANG['validation'][2]="Stāvoklis"; 
$LANG['validation'][3]="Request date"; 
$LANG['validation'][4]="Apstiprinājuma datums"; 
$LANG['validation'][5]="Request comment"; 
$LANG['validation'][6]="Apstiprinājuma piezīmes"; 
$LANG['validation'][7]="Approval(s) for the ticket"; 
$LANG['validation'][9]="Waiting for approval"; 
$LANG['validation'][10]="Refused"; 
$LANG['validation'][11]="Granted"; 
$LANG['validation'][12]="Not subject to approval"; 
$LANG['validation'][13]="Apstiprinājuma lūgumu sūtīt uz"; 
$LANG['validation'][15]="Ticket waiting for your Approval"; 
$LANG['validation'][16]="Optional when approved"; 
$LANG['validation'][18]="Approval requester"; 
$LANG['validation'][19]="Approval granted"; 
$LANG['validation'][20]="Approval denied"; 
$LANG['validation'][21]="Apstiprinātājs"; 
$LANG['validation'][23]="The selected user has no valid emailaddress. The request has been created, without email confirmation."; 
$LANG['validation'][26]="Apstiprinājuma pieprasījums"; 
$LANG['validation'][27]="An approval request has been submitted"; 
$LANG['validation'][28]="Status of the Approval request"; 
$LANG['validation'][29]="If approval is denied, specify a reason"; 
$LANG['validation'][30]="Cancel the approval request to"; 
$LANG['validation'][31]="Update the Approval request to"; 
$LANG['validation'][32]="An answer to a Approval request was produced"; 
$LANG['validation'][33]="Pieteikums gaida apstiprinājumu"; 
?>